@@ -1,36 +1,30 @@
 package Treex::Block::Read::BaseReader;
-{
-  $Treex::Block::Read::BaseReader::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Block::Read::BaseReader::VERSION = '0.05222';
 }
 use Moose;
 use Treex::Core::Common;
-use File::Slurp;
 with 'Treex::Core::DocumentReader';
-use Treex::Core::Document;
 
 sub next_document {
     my ($self) = @_;
-    return log_fatal "method next_document must be overridden in " . ref($self);
+    return log_fatal "method next_document must be overriden in " . ref($self);
 }
 
-has selector => ( isa => 'Treex::Type::Selector', is => 'ro', default => q{} );
-
-# Note that "language" is intentionally not required here,
-# because some derived classes (e.g. Read::Treex) do not need it.
-# However, if a derived class reads a format where the language is not specified,
-# it must add the parameter language using:
-#has language => ( isa => 'Treex::Type::LangCode', is => 'ro', required=>1 );
+has selector => ( isa => 'Selector', is => 'ro', default => '' );
 
+has filenames => (
+    isa           => 'ArrayRef[Str]',
+    is            => 'ro',
+    lazy_build    => 1,
+    documentation => 'array of filenames to be loaded;'
+        . ' automatically initialized from the attribute "from"',
+);
 
 has from => (
-    isa           => 'Treex::Core::Files',
+    isa           => 'Str',
     is            => 'ro',
-    coerce        => 1,
-    required      => 1,
-    handles       => [qw(current_filename file_number _set_file_number)],
-    documentation => 'arrayref of filenames to be loaded, '
-        . 'coerced from a space or comma separated list of filenames, '
-        . 'see POD for details',
+    documentation => 'space or comma separated list of filenames to be loaded',
 );
 
 has file_stem => (
@@ -39,6 +33,15 @@ has file_stem => (
     documentation => 'how to name the loaded documents',
 );
 
+has file_number => (
+    isa           => 'Int',
+    is            => 'ro',
+    writer        => '_set_file_number',
+    default       => 0,
+    init_arg      => undef,
+    documentation => 'Number of input files loaded so far.',
+);
+
 has is_one_doc_per_file => (
     is      => 'rw',
     isa     => 'Bool',
@@ -47,6 +50,18 @@ has is_one_doc_per_file => (
 
 has _file_numbers => ( is => 'rw', default => sub { {} } );
 
+sub _build_filenames {
+    my $self = shift;
+    log_fatal "Parameter 'from' must be defined!" if !defined $self->from;
+    return [split /[ ,]+/, $self->from ];
+}
+
+sub current_filename {
+    my ($self) = @_;
+    return if $self->file_number == 0 || $self->file_number > @{ $self->filenames };
+    return $self->filenames->[ $self->file_number - 1 ];
+}
+
 sub is_next_document_for_this_job {
     my ($self) = @_;
     return 1 if !$self->jobindex;
@@ -54,7 +69,6 @@ sub is_next_document_for_this_job {
 }
 
 sub next_filename {
-    
     my ($self) = @_;
 
     # In parallel processing and one_doc_per_file setting,
@@ -64,9 +78,6 @@ sub next_filename {
         $self->_set_file_number( $self->file_number + 1 );
         $self->_set_doc_number( $self->doc_number + 1 );
     }
-    # return undef, but do not move further if we are at the end of document list (we might need the current file name) 
-    return if ( $self->file_number >= $self->from->number_of_files );
-    
     $self->_set_file_number( $self->file_number + 1 );
     return $self->current_filename();
 }
@@ -74,13 +85,11 @@ sub next_filename {
 use File::Spec;
 
 sub new_document {
-    
     my ( $self, $load_from ) = @_;
     my $path = $self->current_filename();
     log_fatal "next_filename() must be called before new_document()" if !defined $path;
     my ( $volume, $dirs, $file ) = File::Spec->splitpath($path);
     my ( $stem, $extension ) = $file =~ /([^.]+)(\..+)?/;
-    $stem =~ s/^-$/noname/;
     my %args = ( file_stem => $stem, loaded_from => $path );
     if ( defined $dirs ) {
         $args{path} = $volume . $dirs;
@@ -91,7 +100,7 @@ sub new_document {
     }
 
     if ( $self->is_one_doc_per_file && !$self->file_stem ) {
-        $args{file_number} = q{};
+        $args{file_number} = '';
     }
     else {
         my $num = $self->_file_numbers->{$stem};
@@ -104,26 +113,12 @@ sub new_document {
     }
 
     $self->_set_doc_number( $self->doc_number + 1 );
-
-    my $document;
-    if ( defined $load_from and $load_from =~ /\.streex$/ ) {
-        $document = Treex::Core::Document->retrieve_storable($load_from);
-        $document->set_storable(1);
-    }
-    else {
-        $document = Treex::Core::Document->new( \%args );
-    }
-
-    if ( defined $load_from && $load_from =~ /\.gz$/ ) {
-        $document->set_compress(1);
-    }
-
-    return $document;
+    return Treex::Core::Document->new( \%args );
 }
 
 sub number_of_documents {
     my $self = shift;
-    return $self->is_one_doc_per_file ? $self->from->number_of_files : undef;
+    return $self->is_one_doc_per_file ? scalar @{ $self->filenames } : undef;
 }
 
 after 'restart' => sub {
@@ -141,12 +136,12 @@ Treex::Block::Read::BaseReader - abstract ancestor for document readers
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 DESCRIPTION
 
 This class serves as an common ancestor for document readers,
-that have a parameter C<from> with a space or comma separated list of filenames
+that have parameter C<from> with a space or comma separated list of filenames
 to be loaded.
 It is designed to implement the L<Treex::Core::DocumentReader> interface.
 
@@ -159,23 +154,21 @@ and you can use C<next_filename> and C<new_document> methods.
 
 =item from (required)
 
-space or comma separated list of filenames, or C<-> for STDIN
-
-An '@' directly in front of a file name causes this file to be interpreted as a file
-list, with one file name per line, e.g. '@filelist.txt' causes the reader to open
-'filelist.txt' and read a list of files from it. File lists may be arbitrarily 
-mixed with regular files in the parameter. 
-
-(If you use this method via API you can specify a string array reference or a
-L<Treex::Core::Files> object.)
+space or comma separated list of filenames, or "-" for STDIN
+(If you use this method via API you can specify C<filenames> instead.)
 
 =item file_stem (optional)
 
 How to name the loaded documents.
-This attribute will be saved to the same-named
-attribute in documents and it will be used in document writers
+This will attribute will be saved to the same-named
+attdibute in documents and it will be used in documents writers
 to decide where to save the files.
 
+=item filenames (internal)
+
+array of filenames to be loaded,
+automatically initialized from the attribute C<from>
+
 =back
 
 =head1 METHODS
@@ -184,7 +177,7 @@ to decide where to save the files.
 
 =item next_document
 
-This method must be overridden in derived classes.
+This method must be overriden in derived classes.
 (The implementation in this class just issues fatal error.)
 
 =item next_filename
@@ -195,7 +188,7 @@ returns the next filename (full path) to be loaded
 =item new_document($load_from?)
 
 Returns a new empty document with pre-filled attributes
-C<loaded_from>, C<file_stem>, C<file_number> and C<path>
+loaded_from, file_stem, file_number and path
 which are guessed based on C<current_filename>.
 
 =item current_filename
@@ -207,14 +200,14 @@ returns the last filename returned by C<next_filename>
 Is the document that will be returned by C<next_document>
 supposed to be processed by this job?
 This is relevant only in parallel processing,
-where each job has a different C<$jobnumber> assigned.
+where each job has different C<$jobnumber> assigned.
 
 =item number_of_documents
 
 Returns the number of documents that will be read by this reader.
-If C<is_one_doc_per_file> returns C<true>, then the number of documents
+If C<is_one_doc_per_file> returns true, then the number of documents
 equals the number of files given in C<from>.
-Otherwise, this method returns C<undef>.
+Otherwise, this method returns undef.
 
 =back
 
@@ -225,10 +218,10 @@ L<Treex::Block::Read::Text>
 
 =head1 AUTHOR
 
-Martin Popel <popel@ufal.mff.cuni.cz>
+Martin Popel
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2011-2012 by Institute of Formal and Applied Linguistics, Charles University in Prague
+Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
