@@ -1,20 +1,18 @@
 package Treex::Block::Read::BaseTextReader;
-{
-  $Treex::Block::Read::BaseTextReader::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Block::Read::BaseTextReader::VERSION = '0.05222';
 }
 use Moose;
 use Treex::Core::Common;
 extends 'Treex::Block::Read::BaseReader';
-#use File::Slurp 9999;
-use PerlIO::via::gzip;
+use File::Slurp;
 
 # By default read from STDIN
 has '+from' => ( default => '-' );
 
-has language      => ( isa => 'Treex::Type::LangCode', is => 'ro', required => 1 );
-has lines_per_doc => ( isa => 'Int',                   is => 'ro', default  => 0 );
-has merge_files   => ( isa => 'Bool',                  is => 'ro', default  => 0 );
-has encoding      => ( isa => 'Str',                   is => 'ro', default  => 'utf8' );
+has language      => ( isa => 'LangCode', is => 'ro', required => 1 );
+has lines_per_doc => ( isa => 'Int',      is => 'ro', default  => 0 );
+has merge_files   => ( isa => 'Bool',     is => 'ro', default  => 0 );
 
 has _current_fh => ( is => 'rw' );
 
@@ -27,22 +25,15 @@ sub BUILD {
 }
 
 sub next_filehandle {
-
     my ($self) = @_;
     my $filename = $self->next_filename();
     return if !defined $filename;
-    if ( $filename eq '-' ) {
-        binmode STDIN, $self->encoding;
-        return \*STDIN;
-    }
-    my $mode = $filename =~ /[.]gz$/ ? '<:via(gzip):' : '<:';
-    $mode .= $self->encoding;
-    open my $FH, $mode, $filename or log_fatal "Can't open $filename: $!";
+    return \*STDIN if $filename eq '-';
+    open my $FH, '<:utf8', $filename or log_fatal "Can't open $filename: $!";
     return $FH;
 }
 
 sub next_document_text {
-    
     my ($self) = @_;
     my $FH = $self->_current_fh;
     if ( !$FH ) {
@@ -52,8 +43,7 @@ sub next_document_text {
 
     if ( $self->is_one_doc_per_file ) {
         $self->_set_current_fh(undef);
-        local $/ = undef;
-        return <$FH>;
+        return read_file($FH);
     }
 
     my $text = '';
@@ -68,7 +58,6 @@ sub next_document_text {
             $self->_set_current_fh($FH);
             last LINE if !$self->merge_files;
         }
-        
         $text .= <$FH>;
     }
     return $text;
@@ -86,7 +75,7 @@ Treex::Block::Read::BaseTextReader - abstract ancestor for document readers
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 DESCRIPTION
 
@@ -109,16 +98,12 @@ and you can use C<next_document_text> and C<new_document> methods.
 If you want to split one file to more documents.
 The default is 0 which means, don't split.
 
-=item merge_files
+=item merge_file
 
 Merge the content of all files (specified in C<from> attribute) into one stream.
 Useful in combination with C<lines_per_doc> to get equally-sized documents
 even from non-equally-sized files.
 
-=item encoding
-
-What is the encoding of the input files. E.g. C<utf8> (the default), C<cp1250> etc.
-
 =back
 
 =head1 METHODS
@@ -150,4 +135,4 @@ Martin Popel
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
