@@ -1,6 +1,6 @@
 package Treex::Block::Read::Sentences;
-{
-  $Treex::Block::Read::Sentences::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Block::Read::Sentences::VERSION = '0.05222';
 }
 use Moose;
 use Treex::Core::Common;
@@ -31,13 +31,11 @@ Treex::Block::Read::Sentences
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 DESCRIPTION
 
 Document reader for plain text format, one sentence per line.
-The sentences are stored into L<bundles|Treex::Core::Bundle> in the 
-L<document|Treex::Core::Document>.
 
 =head1 ATTRIBUTES
 
@@ -59,14 +57,6 @@ Loads a document.
 
 =back
 
-=head1 SEE
-
-L<Treex::Block::Read::BaseTextReader>
-L<Treex::Core::Document>
-L<Treex::Core::Bundle>
-L<Treex::Block::Read::AlignedSentences>
-
-
 =head1 AUTHOR
 
 Martin Popel
@@ -75,4 +65,4 @@ Martin Popel
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
