@@ -1,6 +1,6 @@
 package Treex::Block::Read::Text;
-{
-  $Treex::Block::Read::Text::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Block::Read::Text::VERSION = '0.05222';
 }
 use Moose;
 use Treex::Core::Common;
@@ -27,14 +27,14 @@ Treex::Block::Read::Text
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 DESCRIPTION
 
 Document reader for plain text format.
-The text is stored to the L<document|Treex::Core::Document>'s attribute C<text>,
-if you want to load a text in "on sentence per line" format to
-L<bundles|Treex::Core::Bundle>, use L<Treex::Block::Read::Sentences> instead.
+The text is stored to the document's attribute C<text>,
+if you want to load a text in "on sentence per line" format to bundles,
+use L<Treex::Block::Read::Sentences>.
 
 =head1 ATTRIBUTES
 
@@ -64,4 +64,4 @@ Martin Popel
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
