@@ -1,6 +1,6 @@
 package Treex::Block::Util::DefinedAttr;
-{
-  $Treex::Block::Util::DefinedAttr::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Block::Util::DefinedAttr::VERSION = '0.05222';
 }
 use Moose;
 use Treex::Core::Common;
@@ -54,8 +54,10 @@ sub check_tree {
         foreach my $name ( split /,/, $attrs ) {
             my $value = $node->get_attr($name);
             if ( !defined $value ) {
-                my $address = $node->get_address();
-                my $msg     = "${layer}node\t$address\tundefined attr_name=$name\t" . $self->message;
+                my $id = $node->id || '?';
+
+                #TODO print doc name, bundle id etc.
+                my $msg = "${layer}node id=$id\tattr_name=$name\t" . $self->message;
                 log_fatal($msg) if $self->on_error eq 'die';
                 log_warn($msg);
             }
@@ -72,11 +74,11 @@ __END__
 
 =head1 NAME
 
-Treex::Block::Util::DefinedAttr - Special block for checking C<undef> attributes
+Treex::Block::Util::DefinedAttr - Special block for checking undef attributes
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 SYNOPSIS
 
@@ -94,12 +96,12 @@ version 0.08633_1
 
 Warns/dies if a given attribute is undefined (in any node).
 
-One of parameters C<tnode>, C<anode>, C<nnode>, C<pnode> must be always specified.
-By default: C<on_error=warn> and C<message> is empty.
+One of parameters tnode, anode, nnode, pnode must be always specified.
+By default: on_error=warn and message is empty.
 
 
 =head1 COPYRIGHT AND LICENSE
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
