@@ -1,6 +1,6 @@
 package Treex::Block::Util::Eval;
-{
-  $Treex::Block::Util::Eval::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Block::Util::Eval::VERSION = '0.05222';
 }
 use Moose;
 use Treex::Core::Common;
@@ -25,7 +25,7 @@ sub BUILD {
     $arg_ref->{_bundle} = any { $arg_ref->{$_} } qw(bundle _zone);
 
     if ( !any { $arg_ref->{$_} } qw(document _bundle) ) {
-        log_fatal "At least one of the following parameters must be non-empty:"
+        log_fatal "You must specify at least one of the parameters:"
             . " document, bundle, zone, [atnp]tree, [atnp]node.";
     }
 
@@ -43,30 +43,22 @@ sub BUILD {
 ## no critic (ProhibitStringyEval) This block needs string evals
 sub process_document {
     my ( $self, $document ) = @_;
-    my $doc = $document;
     if ( $self->document ) {
-        my $to_eval = $self->document . ';1;';
-        eval($to_eval) or log_fatal("While evaluating '$to_eval' got error: $@");
+        if ( !eval $self->document . ';1;' ) {
+            log_fatal "Eval error: $@";
+        }
     }
 
     if ( $self->_args->{_bundle} ) {
-        my $bundleNo = 1;
         foreach my $bundle ( $document->get_bundles() ) {
-            if ( !$self->grep_bundle || $self->grep_bundle == $bundleNo ) {
-                $self->process_bundle($bundle, $bundleNo);
-            }
-            $bundleNo++;
+            $self->process_bundle($bundle);
         }
     }
     return;
 }
 
 sub process_bundle {
-    my ( $self, $bundle, $bundleNo ) = @_;
-
-    # Extract variables $document ($doc), so they can be used in eval code
-    my $document = $bundle->get_document();
-    my $doc      = $document;
+    my ( $self, $bundle ) = @_;
     if ( $self->bundle ) {
         if ( !eval $self->bundle . ';1;' ) {
             log_fatal "Eval error: $@";
@@ -85,8 +77,7 @@ sub process_bundle {
     }
 
     foreach my $zone ( $bundle->get_all_zones() ) {
-        if ( ( $do_lang{ $zone->language } || $self->language eq 'mul' )
-                 && $do_sele{ $zone->selector } ) {
+        if ( $do_lang{ $zone->language } && $do_sele{ $zone->selector } ) {
             $self->process_zone($zone);
         }
     }
@@ -96,11 +87,6 @@ sub process_bundle {
 
 sub process_zone {
     my ( $self, $zone ) = @_;
-
-    # Extract variables $bundle, $document ($doc), so they can be used in eval code
-    my $bundle   = $zone->get_bundle();
-    my $document = $bundle->get_document();
-    my $doc      = $document;
     if ( $self->zone ) {
         if ( !eval $self->zone . ';1;' ) {
             log_fatal "Eval error: $@";
@@ -136,7 +122,7 @@ Treex::Block::Util::Eval - Special block for evaluating code given by parameters
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 SYNOPSIS
 
@@ -150,15 +136,10 @@ version 0.08633_1
 
 =head1 DESCRIPTION
 
-Evaluate an arbitrary Perl code for each document/block/tree/node on the specified layer (according to which parameter 
-is given). The corresponding object is accessible through a variable of the same name. 
 
-=head1 AUTHOR
-
-Martin Popel <popel@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
