@@ -1,14 +1,18 @@
 package Treex::Block::Write::Sentences;
-{
-  $Treex::Block::Write::Sentences::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Block::Write::Sentences::VERSION = '0.05222';
 }
 use Moose;
 use Treex::Core::Common;
-extends 'Treex::Block::Write::BaseTextWriter';
+extends 'Treex::Core::Block';
 
 has '+language' => ( required => 1 );
 
-has '+extension' => ( default => '.txt' );
+has encoding => (
+    is            => 'ro',
+    default       => 'utf8',
+    documentation => 'Output encoding. By default utf8.',
+);
 
 has join_resegmented => (
     is            => 'ro',
@@ -18,14 +22,20 @@ has join_resegmented => (
         . ' by W2A::ResegmentSentences on one line.',
 );
 
+sub BUILD {
+    my ($self) = @_;
+    binmode STDOUT, ':encoding(' . $self->encoding . ')';
+    return;
+}
+
 sub process_zone {
     my ( $self, $zone ) = @_;
     my $bundle_id = $zone->get_bundle()->id;
     if ( $self->join_resegmented && $bundle_id =~ /_(\d+)of(\d+)$/ && $1 != $2 ) {
-        print { $self->_file_handle } $zone->sentence, " ";
+        print $zone->sentence, " ";
     }
     else {
-        print { $self->_file_handle } $zone->sentence, "\n";
+        print $zone->sentence, "\n";
     }
     return;
 }
@@ -40,12 +50,11 @@ Treex::Block::Write::Sentences
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 DESCRIPTION
 
-Document writer for plain text format, one sentence
-(L<bundle|Treex::Core::Bundle>) per line.
+Document writer for plain text format, one sentence per line.
 
 
 =head1 ATTRIBUTES
@@ -54,16 +63,12 @@ Document writer for plain text format, one sentence
 
 =item encoding
 
-Output encoding. C<utf8> by default.
+Output encoding. By default utf8.
 
 =item join_resegmented
 
 Print the sentences re-segmented
-by L<Treex::Block::W2A::ResegmentSentences> on one line.
-
-=item to
-
-The name of the output file, STDOUT by default.
+by C<W2A::ResegmentSentences> on one line.
 
 =back
 
@@ -85,4 +90,4 @@ Martin Popel
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
