@@ -1,27 +1,20 @@
 package Treex::Block::Write::Text;
-{
-  $Treex::Block::Write::Text::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Block::Write::Text::VERSION = '0.05222';
 }
 use Moose;
 use Treex::Core::Common;
-extends 'Treex::Block::Write::BaseTextWriter';
+extends 'Treex::Core::Block';
 
-has '+language' => ( required => 1 );
+#TODO implement "to"
+has to => ( isa => 'Str', is => 'ro', default => '-' );
 
-has '+extension' => ( default => '.txt' );
-
-override 'process_document' => sub {
-  
+sub process_document {
     my ( $self, $doc ) = @_;
-
-    $self->_prepare_file_handle($doc);    # open the output file handle
-
     my $doczone = $doc->get_zone( $self->language, $self->selector );
-  
-    print { $self->_file_handle } $doczone->text;
-  
+    print $doczone->text;
     return;
-};
+}
 
 1;
 
@@ -33,13 +26,13 @@ Treex::Block::Write::Text
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 DESCRIPTION
 
 Document writer for plain text format.
 The text is taken from the document's attribute C<text>,
-if you want to save the sentences stored in L<bundles|Treex::Core::Bundle>,
+if you want to save the sentences stored in bundles,
 use L<Treex::Block::Write::Sentences>.
 
 
@@ -66,10 +59,10 @@ Saves the document.
 
 =head1 AUTHOR
 
-Martin Popel <popel@ufal.mff.cuni.cz>
+Martin Popel
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2011-2012 by Institute of Formal and Applied Linguistics, Charles University in Prague
+Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
