@@ -1,16 +1,13 @@
 package Treex::Core::Bundle;
-{
-  $Treex::Core::Bundle::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::Bundle::VERSION = '0.05222';
 }
 
-use namespace::autoclean;
-
 use Moose;
 use Treex::Core::Common;
 use MooseX::NonMoose;
 
 extends 'Treex::PML::Node';
-with 'Treex::Core::WildAttr';
 
 has document => (
     is       => 'ro',
@@ -30,6 +27,8 @@ use Treex::Core::BundleZone;
 
 use Treex::Core::Log;
 
+my @layers = qw(t a n);
+
 # --------- ACCESS TO ZONES ------------
 
 sub BUILD {
@@ -42,16 +41,13 @@ sub get_zone {
     my $self = shift;
     my ( $language, $selector ) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::LangCode' },
-        { isa => 'Treex::Type::Selector', default => '' },
+        { isa => 'LangCode' },
+        { isa => 'Selector', default => '' },
     );
     if ( defined $self->{zones} ) {
         foreach my $element ( $self->{zones}->elements ) {
             my ( undef, $value ) = @$element;    # $name is not needed
-            if (( $value->{language} eq $language or $language eq 'mul' )
-                and ( $value->{selector} || '' ) eq $selector
-                )
-            {
+            if ( $value->{language} eq $language and ( $value->{selector} || '' ) eq $selector ) {
                 return $value;
             }
         }
@@ -61,25 +57,11 @@ sub get_zone {
 
 sub create_zone {
     my $self = shift;
-    my ( $language, $selector, $params_rf ) = pos_validated_list(
+    my ( $language, $selector ) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::LangCode' },
-        { isa => 'Treex::Type::Selector', default => '' },
-        { isa => 'Ref' },
+        { isa => 'LangCode' },
+        { isa => 'Selector', default => '' },
     );
-
-    if ( $self->get_zone( $language, $selector ) ) {
-        if (defined $params_rf and $params_rf->{overwrite}) {
-
-        }
-        else {
-            log_fatal("Bundle already contains a zone with language='$language' and selector='$selector'. "
-                          . "Use create_zone(...,{overwrite=>1}) to remove it first.")
-        }
-    }
-
-
-
     my $new_zone = Treex::Core::BundleZone->new(
         {
             'language' => $language,
@@ -107,11 +89,11 @@ sub get_or_create_zone {
     my $self = shift;
     my ( $language, $selector ) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::LangCode' },
-        { isa => 'Treex::Type::Selector', default => '' },
+        { isa => 'LangCode' },
+        { isa => 'Selector', default => '' },
     );
     my $zone = $self->get_zone( $language, $selector );
-    if ( !defined $zone ) {
+    if ( not defined $zone ) {
         $zone = $self->create_zone( $language, $selector );
     }
     return $zone;
@@ -119,60 +101,12 @@ sub get_or_create_zone {
 
 sub get_all_zones {
     my $self = shift;
-    if ( $self->{zones} ) {
-        return map { $_->value() } $self->{zones}->elements;
-    }
-    else {
-        return ();
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
     }
+    return map { $_->value() } $self->{zones}->elements;
 }
 
-sub remove_zone {
-    my ( $self, $language, $selector ) = @_;
-
-    my $zone = $self->get_zone( $language, $selector );
-    if ( !$zone ) {
-        log_fatal "Non-existing zone cannot be removed";
-    }
-
-    # remove all trees first, so that their nodes are correctly removed from the index
-    foreach my $tree ( $zone->get_all_trees ) {
-        $zone->remove_tree( $tree->get_layer );
-    }
-
-    $self->{zones}->delete_value($zone)
-        or log_fatal "Zone to be deleted was not found. This should never happen";
-    return;
-}
-
-sub remove {
-    my ( $self ) = @_;
-
-    # clean the bundle's content first (to ensure de-indexing)
-    foreach my $zone ( $self->get_all_zones ) {
-        $self->remove_zone( $zone->language, $zone->selector );
-    }
-
-    my $position = 0;
-
-    # find the bundle's position (this is quite inefficient, as the info about
-    # bundle's position is stored nowhere), and delete the bundle using Treex::PML API
-  BUNDLE:
-    foreach my $bundle ( $self->get_document->get_bundles ) {
-        if ( $bundle eq $self ) {
-            last BUNDLE;
-        }
-        else {
-            $position++;
-        }
-    }
-
-    $self->get_document->delete_tree($position);
-    bless $self, 'Treex::Core::Node::Removed';
-    return;
-}
-
-
 # --------- ACCESS TO TREES ------------
 
 sub get_all_trees {
@@ -186,8 +120,7 @@ sub get_all_trees {
     my @trees;
     foreach my $zone ( $self->{zones}->elements ) {
         my $structure = $zone->value;
-        foreach my $layer (Treex::Core::Types::layers()) {
-            $layer = lc $layer;
+        foreach my $layer (@layers) {
             if ( exists $structure->{trees}->{"${layer}_tree"} ) {
                 push @trees, $structure->{trees}->{"${layer}_tree"};
             }
@@ -201,9 +134,9 @@ sub create_tree {
     my $self = shift;
     my ( $language, $layer, $selector ) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::LangCode' },
-        { isa => 'Treex::Type::Layer' },
-        { isa => 'Treex::Type::Selector', default => '' }
+        { isa => 'LangCode' },
+        { isa => 'Layer' },
+        { isa => 'Selector', default => '' }
     );
 
     my $zone = $self->get_or_create_zone( $language, $selector );
@@ -215,9 +148,9 @@ sub get_tree {
     my $self = shift;
     my ( $language, $layer, $selector ) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::LangCode' },
-        { isa => 'Treex::Type::Layer' },
-        { isa => 'Treex::Type::Selector', default => '' }
+        { isa => 'LangCode' },
+        { isa => 'Layer' },
+        { isa => 'Selector', default => '' }
     );
 
     my $zone = $self->get_zone( $language, $selector );
@@ -229,14 +162,68 @@ sub has_tree {
     my $self = shift;
     my ( $language, $layer, $selector ) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::LangCode' },
-        { isa => 'Treex::Type::Layer' },
-        { isa => 'Treex::Type::Selector', default => '' }
+        { isa => 'LangCode' },
+        { isa => 'Layer' },
+        { isa => 'Selector', default => '' }
     );
     my $zone = $self->get_zone( $language, $selector );
     return defined $zone && $zone->has_tree($layer);
 }
 
+# --------- ACCESS TO ATTRIBUTES ------------
+
+sub set_attr {    # deprecated
+    my $self = shift;
+    my ( $attr_name, $attr_value ) = pos_validated_list(
+        \@_,
+        { isa => 'Str' },
+        { isa => 'Any' },
+    );
+
+    if ( $attr_name =~ /^(\S+)$/ ) {
+        return Treex::PML::Node::set_attr( $self, $attr_name, $attr_value );
+    }
+
+    # TODO more selectors than [ST], lang-codes with more letters etc.
+    elsif ( $attr_name =~ /^([ST])([a-z]{2}) (\S+)$/ ) {
+        my ( $selector, $language, $attr_name ) = ( $1, $2, $3 );
+        my $zone = $self->get_or_create_zone( $language, $selector );
+        return $zone->{$attr_name} = $attr_value;
+    }
+
+    else {
+        log_fatal "Attribute name not structured approapriately (e.g.'Sar text'): $attr_name";
+    }
+}
+
+sub get_attr {    # deprecated
+    my $self = shift;
+    my ($attr_name) = pos_validated_list(
+        \@_,
+        { isa => 'Str' },
+    );
+
+    if ( $attr_name =~ /^(\S+)$/ ) {
+        return Treex::PML::Node::attr( $self, $attr_name );
+    }
+
+    elsif ( $attr_name =~ /^([ST])([a-z]{2}) (\S+)$/ ) {
+        my ( $selector, $language, $attr_name ) = ( $1, $2, $3 );
+        my $zone = $self->get_zone( $language, $selector );
+        if ( defined $zone ) {
+            return $zone->{$attr_name};
+        }
+        else {
+            return;
+        }
+    }
+
+    else {
+        log_fatal "Attribute name not structured approapriately (e.g.'Sar sentence'): $attr_name";
+    }
+}
+
+# numbering of bundles starts from 0
 sub get_position {
     my ($self) = @_;
 
@@ -251,30 +238,13 @@ sub get_position {
         }
     }
 
-    if ( !defined $position_of_reference ) {
+    if ( not defined $position_of_reference ) {
         log_fatal "document structure inconsistency: can't detect position of bundle $self";
     }
 
     return $position_of_reference;
 }
 
-# --------- ACCESS TO ATTRIBUTES ------------
-
-sub get_attr {
-    my $self = shift;
-    my ($attr_name) = pos_validated_list(
-        \@_,
-        { isa => 'Str' },
-    );
-    return $self->{$attr_name};
-}
-
-# ------- other -------------
-
-sub following {
-    Treex::Core::Node::following(@_);
-}
-
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -288,20 +258,19 @@ __END__
 
 =head1 NAME
 
-Treex::Core::Bundle - a set of equivalent sentences in the Treex framework
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
+Treex::Core::Bundle - a set of equivalent sentences (translations, or variants)
+and their linguistic representations in the Treex framework
 
 =head1 DESCRIPTION
 
-A set of equivalent sentences (translations, or variants) and their linguistic representations in the Treex framework
-A bundle in Treex corresponds to one sentence or more sentences, typically 
-translations or variants of each other, with all their linguistic 
-representations. Each bundle is divided into zones (instances of 
-L<Treex::Core::BundleZone>), each of them containing 
-exactly one sentence and its representations.
+A bundle in Treex corresponds to one sentence or more sentences, typically translations
+or variants of each other, with all their linguistic representations. Each bundle
+is divided into zones (instances of Treex::Core::BundleZone), each of them
+containing exactly one sentence and its representations.
 
 =head1 ATTRIBUTES
 
@@ -311,13 +280,12 @@ Each bundle has two attributes:
 
 =item id
 
-identifier accessible by the getter method C<id()> and by the setter method 
-C<set_id($id)>
+identifier accessible by the getter method C<id()> and by the setter method C<set_id($id)>
 
 =item document
 
-the document (an instance of L<Treex::Core::Document>) 
-which this bundle belongs to; accessible only by the getter method C<document()>
+the document (an instance of Treex::Core::Document) which this bundle belongs to;
+accessible only by the getter method C<document()>
 
 =back
 
@@ -327,9 +295,8 @@ which this bundle belongs to; accessible only by the getter method C<document()>
 
 =head2 Construction
 
-You cannot create a bundle by a constructor from scratch. You can create a 
-bundle only within an existing documents, using the following methods of 
-L<Treex::Core::Document>:
+You cannot create a bundle by a constructor from scratch. You can create a bundle
+only within an existing documents, using the following methods of Treex::Core::Document:
 
 =over 4
 
@@ -344,18 +311,14 @@ L<Treex::Core::Document>:
 
 =head2 Access to zones
 
-Bundle zones are instances of 
-L<Treex::Core::BundleZone>, parametrized by language 
-code and possibly also by another free label called selector, whose purpose is 
-to distinguish zones for the same language but from a different source.
+Bundle zones are instances of Treex::Core::BundleZone, parametrized
+by language code and possibly also by another free label
+called selector, whose purpose is to distinguish zones for the same language
+but from a different source.
 
 =over 4
 
-=item my $zone = $bundle->create_zone( $langcode, ?$selector, ?$params_rf );
-
-If the third argument is {overwrite=>1}, then the newly created empty zone
-overwrites the previously existing one (if any). Fatal error appears if
-the zone to be created already exists and this switch is not used.
+=item my $zone = $bundle->create_zone( $langcode, ?$selector );
 
 =item my $zone = $bundle->get_zone( $langcode, ?$selector );
 
@@ -368,8 +331,8 @@ the zone to be created already exists and this switch is not used.
 
 =head2 Access to trees
 
-Even if trees are not contained directly in bundle (there is the intermediate 
-zone level), they can be accessed using the following shortcut methods:
+Even if trees are not contained directly in bundle (there is the intermediate zone level),
+they can be accessed using the following shortcut methods:
 
 =over 4
 
@@ -392,10 +355,6 @@ zone level), they can be accessed using the following shortcut methods:
 
 =over 4
 
-=item $bundle->remove_zone( $language, $selector );
-
-delete all zone's trees and remove the zone from the bundle
-
 =item my $position = $bundle->get_position();
 
 position of the bundle within the document (number, starting from 0)
@@ -411,4 +370,4 @@ Zdeněk Žabokrtský <zabokrtsky@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
