@@ -1,6 +1,6 @@
 package Treex::Core::BundleZone;
-{
-  $Treex::Core::BundleZone::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::BundleZone::VERSION = '0.05222';
 }
 
 use Moose;
@@ -10,7 +10,6 @@ use MooseX::NonMoose;
 use Treex::Core::Node::A;
 use Treex::Core::Node::T;
 use Treex::Core::Node::N;
-use Treex::Core::Node::P;
 
 extends 'Treex::Core::Zone';
 
@@ -27,65 +26,66 @@ sub _set_bundle {
 
 sub get_bundle {
     my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
     return $self->get_attr('_bundle');
 }
 
 sub get_document {
     my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
     return $self->get_bundle->get_document;
 }
 
 sub create_atree {
-    my ($self,$params_rf) = @_;
-    return $self->create_tree('a',$params_rf);
+    my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
+    return $self->create_tree('a');
 }
 
 sub create_ttree {
-    my ($self,$params_rf) = @_;
-    return $self->create_tree('t',$params_rf);
+    my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
+    return $self->create_tree('t');
 }
 
 sub create_ntree {
-    my ($self,$params_rf) = @_;
-    return $self->create_tree('n',$params_rf);
+    my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
+    return $self->create_tree('n');
 }
 
 sub create_ptree {
-    my ($self,$params_rf) = @_;
-    return $self->create_tree('p',$params_rf);
+    my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
+    return $self->create_tree('p');
 }
 
 sub create_tree {
     my $self = shift;
-    my ($layer,$params_rf) = pos_validated_list(
+    my ($layer) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::Layer' },
-        { isa => 'Ref' },
+        { isa => 'Layer' },
     );
-    $layer = lc $layer;
-
-    if ($self->has_tree($layer)) {
-        if (defined $params_rf and $params_rf->{overwrite}) {
-            $self->remove_tree($layer);
-        }
-        else {
-            log_fatal("Zone already contains tree at $layer layer");
-        }
-    }
-
-    #my $class = "Treex::Core::Node::" . uc($layer);
-    #my $tree_root = eval { $class->new( { _called_from_core_ => 1 } ) } or log_fatal $!;    #layer subclasses not available yet
-    my $opts = { _called_from_core_ => 1 };
-    my $tree_root = $layer eq 'a' ? Treex::Core::Node::A->new($opts)
-                  : $layer eq 't' ? Treex::Core::Node::T->new($opts)
-                  : $layer eq 'n' ? Treex::Core::Node::N->new($opts)
-                  : $layer eq 'p' ? Treex::Core::Node::P->new($opts)
-                  : log_fatal "Cannot create tree for unknown layer $layer";
+    log_fatal("Zone already contains tree at $layer layer") if $self->has_tree($layer);
+    my $class = "Treex::Core::Node::" . uc($layer);
+    my $tree_root = eval { $class->new( { _called_from_core_ => 1 } ) } or log_fatal $!;    #layer subclasses not available yet
 
     my $bundle = $self->get_bundle;
     $tree_root->_set_zone($self);
 
-    my $new_tree_name = $layer . "_tree";
+    my $new_tree_name = lc($layer) . "_tree";
     $self->{trees}->{$new_tree_name} = $tree_root;
 
     my $new_id = "$new_tree_name-" . $self->get_label . "-" . $bundle->get_id . "-root";
@@ -109,13 +109,13 @@ sub remove_tree {
     my $self = shift;
     my ($layer) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::Layer' },
+        { isa => 'Layer' },
     );
 
-    # remove all nodes ($tree_root->remove does not work, in order to not be used by users)
+    # disconnect all nodes ($tree_root->disconnect does not work, in order to not be used by users)
     my $tree_root = $self->get_tree($layer);
     foreach my $child ( $tree_root->get_children() ) {
-        $child->remove();
+        $child->disconnect();
     }
     if ( $tree_root->id ) {
         $self->get_document->index_node_by_id( $tree_root->id, undef );
@@ -128,7 +128,7 @@ sub get_tree {
     my $self = shift;
     my ($layer) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::Layer' },
+        { isa => 'Layer' },
     );
 
     my $tree_name = lc($layer) . "_tree";
@@ -142,21 +142,33 @@ sub get_tree {
 
 sub get_atree {
     my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
     return $self->get_tree('a');
 }
 
 sub get_ttree {
     my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
     return $self->get_tree('t');
 }
 
 sub get_ntree {
     my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
     return $self->get_tree('n');
 }
 
 sub get_ptree {
     my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
     return $self->get_tree('p');
 }
 
@@ -164,7 +176,7 @@ sub has_tree {
     my $self = shift;
     my ($layer) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::Layer' },
+        { isa => 'Layer' },
     );
     my $tree_name = lc($layer) . "_tree";
     return defined $self->{trees}->{$tree_name};
@@ -172,26 +184,41 @@ sub has_tree {
 
 sub has_atree {
     my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
     return $self->has_tree('a');
 }
 
 sub has_ttree {
     my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
     return $self->has_tree('t');
 }
 
 sub has_ntree {
     my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
     return $self->has_tree('n');
 }
 
 sub has_ptree {
     my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
     return $self->has_tree('p');
 }
 
 sub get_all_trees {
     my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
 
     return grep {defined}
         map     { $self->{trees}->{ $_ . "_tree" }; } qw(a t n p);
@@ -199,6 +226,9 @@ sub get_all_trees {
 
 sub sentence {
     my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
     return $self->get_attr('sentence');
 }
 
@@ -211,29 +241,6 @@ sub set_sentence {
     return $self->set_attr( 'sentence', $text );
 }
 
-sub copy {
-    my $self      = shift;
-    my $selector1 = shift;
-
-    # Get the bundle the zone is in.
-    my $bundle = $self->get_bundle();
-    my $zone1 = $bundle->get_or_create_zone( $self->language(), $selector1 );
-    ### TO DO: copy other trees, too (currently only copies a-tree and p-tree)
-    if($self->has_atree())
-    {
-        my $aroot0 = $self->get_atree();
-        my $aroot1 = $zone1->create_atree();
-        $aroot0->copy_atree($aroot1);
-    }
-    if($self->has_ptree())
-    {
-        my $proot0 = $self->get_ptree();
-        my $proot1 = $zone1->create_ptree();
-        $proot0->copy_ptree($proot1);
-    }
-    return $zone1;
-}
-
 1;
 
 __END__
@@ -244,11 +251,11 @@ __END__
 
 =head1 NAME
 
-Treex::Core::BundleZone - contains a sentence and its linguistic representations
+Treex::Core::BundleZone - zone in a bundle containing a sentence and its linguistic representations
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 SYNOPSIS
 
@@ -268,7 +275,7 @@ translation, test translation).
 
 =head1 ATTRIBUTES
 
-C<Treex::Core::BundleZone> instances have the following attributes:
+Treex::Core::BundleZone instances have the following attributes:
 
 =over 4
 
@@ -280,19 +287,18 @@ C<Treex::Core::BundleZone> instances have the following attributes:
 
 =back
 
-The attributes can be accessed using semi-affordance accessors: getters have
-the same names as attributes, while setters start with C<set_>. For example,
-the attribute C<sentence> has a getter C<sentence()> and a setter
-C<set_sentence($sentence)>
+The attributes can be accessed using semi-affordance accessors:
+getters have the same names as attributes, while setters start with
+'set_'. For example by getter C<sentence()> and setter C<set_sentence($sentence)>
 
 
 =head1 METHODS
 
 =head2 Construction
 
-C<Treex::Core::BundleZone> instances should not be created by the constructor,
+Treex::Core::BundleZone instances should not be created by the constructor,
 but should be created exclusively by calling one of the following methods
-of the embedding  L<Treex::Core::Bundle> instance:
+of the embedding  Treex::Core::Bundle instance:
 
 =over 4
 
@@ -306,8 +312,8 @@ of the embedding  L<Treex::Core::Bundle> instance:
 =head2 Access to trees
 
 There are four types of linguistic trees distinguished in Treex, each of them represented
-by one letter: I<a> - analytical treex, I<t> - tectogrammatical trees, I<p> - phrase-structure trees,
-I<n> - named entity trees. You can create trees by following methods:
+by one letter: a - analytical treex, t - tectogrammatical trees, p - phrase-structure trees,
+n - named entity trees. You can create trees by following methods:
 
 =over 4
 
@@ -375,22 +381,11 @@ You can remove trees by
 
 =item $bundle = $zone->get_bundle();
 
-returns the L<Treex::Core::Bundle> instance which the zone belongs to
+returns the Treex::Core::Bundle instance which the zone belongs to
 
 =item $doc = $zone->get_document();
 
-returns the L<Treex::Core::Document> instance which the zone belongs to
-
-=back
-
-
-=head2 Other
-
-=over 4
-
-=item $zone1 = $zone0->copy($selector1);
-
-creates a copy of the zone (currently copies only the a-tree) under the same language and a new selector
+returns the Treex::Core::Document instance which the zone belongs to
 
 =back
 
@@ -404,4 +399,4 @@ Martin Popel <popel@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
