@@ -1,20 +1,15 @@
 package Treex::Core::Common;
-{
-  $Treex::Core::Common::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::Common::VERSION = '0.05222';
 }
-use strict;
-use warnings;
-use 5.010;
-
 use utf8;
+use Moose;
 use Moose::Exporter;
 use Moose::Util::TypeConstraints;
-use MooseX::SemiAffordanceAccessor::Role::Attribute 0.09;
+use MooseX::SemiAffordanceAccessor::Role::Attribute;
 use Treex::Core::Log;
 use Treex::Core::Config;
 use Treex::Core::Resource;
-use Treex::Core::Types;
-use Treex::Core::Files;
 use List::MoreUtils;
 use List::Util;
 use Scalar::Util;
@@ -39,7 +34,7 @@ sub pos_validated_list {
     return @{$args_ref};
 }
 
-# Choose which variant to use according to $Treex::Core::Config::params_validate
+# Choose which variant to use according to Treex::Core::Config::$params_validate
 if ( $Treex::Core::Config::params_validate == 2 ) {    ## no critic (ProhibitPackageVars)
     require MooseX::Params::Validate;
     $validation_sub = \&MooseX::Params::Validate::pos_validated_list;
@@ -51,6 +46,7 @@ else {
 my ( $import, $unimport, $init_meta ) =
     Moose::Exporter->build_import_methods(
     install         => [qw(unimport init_meta)],
+    also            => 'Moose',
     class_metaroles => { attribute => ['MooseX::SemiAffordanceAccessor::Role::Attribute'] },
     as_is           => [
         \&Treex::Core::Log::log_fatal,
@@ -58,9 +54,6 @@ my ( $import, $unimport, $init_meta ) =
         \&Treex::Core::Log::log_debug,
         \&Treex::Core::Log::log_set_error_level,
         \&Treex::Core::Log::log_info,
-        \&Treex::Core::Types::get_lang_name,
-        \&Treex::Core::Types::is_lang_code,
-        \&Treex::Core::Resource::require_file_from_share,
         \&List::MoreUtils::first_index,
         \&List::MoreUtils::all,
         \&List::MoreUtils::any,
@@ -74,11 +67,56 @@ my ( $import, $unimport, $init_meta ) =
     );
 
 sub import {
-    feature->import(':5.10');
     utf8::import();
     goto &$import;
 }
 
+subtype 'Selector'
+    => as 'Str'
+    => where {m/^[a-z\d]*$/i}
+=> message {"Selector must =~ /^[a-z\\d]*\$/i. You've provided $_"};    #TODO: this messege is not printed
+
+subtype 'Layer'
+    => as 'Str'
+    => where {m/^[ptan]$/i}
+=> message {"Layer must be one of: [P]hrase structure, [T]ectogrammatical, [A]nalytical, [N]amed entities, you've provided $_"};
+
+subtype 'Message'                                                       #nonempty string
+    => as 'Str'
+    => where { $_ ne '' }
+=> message {"Message must be nonempty"};
+
+subtype 'Id'
+    => as 'Str';                                                        #preparation for possible future constraints
+
+# ISO 639-1 language code with some extensions from ISO 639-2
+use Locale::Language;
+my %EXTRA_LANG_CODES = (
+    'bxr'     => "Buryat",
+    'dsb'     => "Lower Sorbian",
+    'hsb'     => "Upper Sorbian",
+    'hak'     => "Hakka",
+    'kaa'     => "Karakalpak",
+    'ku-latn' => "Kurdish in Latin script",
+    'ku-arab' => "Kurdish in Arabic script",
+    'ku-cyrl' => "Kurdish in Cyrillic script",
+    'nan'     => "Taiwanese",
+    'rmy'     => "Romany",
+    'sah'     => "Yakut",
+    'und'     => "ISO 639-2 code for undetermined/unknown language",
+    'xal'     => "Kalmyk",
+    'yue'     => "Cantonese"
+);
+
+my %IS_LANG_CODE = map { $_ => 1 } ( all_language_codes(), keys %EXTRA_LANG_CODES );
+enum 'LangCode' => keys %IS_LANG_CODE;
+sub is_lang_code { return $IS_LANG_CODE{ $_[0] }; }
+
+sub get_lang_name {
+    my $code = shift;
+    return exists $EXTRA_LANG_CODES{$code} ? $EXTRA_LANG_CODES{$code} : code2language($code);
+}
+
 1;
 
 __END__
@@ -87,11 +125,11 @@ __END__
 
 =head1 NAME
 
-Treex::Core::Common - shorten the "C<use>" part of your Perl codes
+Treex::Core::Common - shorten the "use" part of your Perl codes
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 SYNOPSIS
 
@@ -104,14 +142,13 @@ Instead of
  use utf8;
  use strict;
  use warnings;
+ use Moose;
  use Moose::Util::TypeConstraints qw(enum);
  use MooseX::SemiAffordanceAccessor;
  use MooseX::Params::Validate qw(pos_validated_list);
  use Treex::Core::Log;
  use Treex::Core::Config;
  use Treex::Core::Resource;
- use Treex::Core::Types;
- use Treex::Core::Files;
  use List::MoreUtils qw(all any first_index);
  use List::Util qw(first);
  use Scalar::Util qw(weaken);
@@ -129,11 +166,10 @@ Instead of
 
 =item pos_validated_list
 
-This subroutine is automatically exported. Depending on the value of 
-L<$Treex::Core::Config::params_validate|Treex::Core::Config/params_validate> 
-it is either the (slow) one from 
-L<MooseX::Params::Validate> or a fast one, that does 
-no type checking.
+This subroutine is automatically exported.
+Depending on the value of C<$Treex::Core::Config::params_validate>
+it is either the (slow) one from L<MooseX::Params::Validate>
+or a fast one, that does no type checking.
 
 =back
 
@@ -145,4 +181,4 @@ Martin Popel <popel@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
