@@ -1,6 +1,6 @@
 package Treex::Core::DocZone;
-{
-  $Treex::Core::DocZone::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::DocZone::VERSION = '0.05222';
 }
 
 use Moose;
@@ -22,7 +22,7 @@ Treex::Core::DocZone - document zone for the text attribute
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 SYNOPSIS
 
@@ -55,14 +55,14 @@ Treex::Core::DocZone instances have the following attributes:
 
 The attributes can be accessed using semi-affordance accessors:
 getters have the same names as attributes, while setters start with
-'C<set_>'. For example, the attribute C<text> has a getter C<text()> and a setter C<set_text($text)>
+'set_'. For example by getter C<text()> and setter C<set_text($text)>
 
 
 =head1 METHODS
 
-=head2 Construction
+-head2 Construction
 
-C<Treex::Core::DocZone> instances should not be created by a constructor,
+Treex::Core::DocZone instances should not be created by a constructor,
 but should be created exclusively from the embedding document
 by one of the document's methods:
 
@@ -83,4 +83,4 @@ Zdeněk Žabokrtský <zabokrtsky@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
