@@ -1,6 +1,6 @@
 package Treex::Core::Document;
-{
-  $Treex::Core::Document::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::Document::VERSION = '0.05222';
 }
 
 use Moose;
@@ -11,26 +11,14 @@ use Treex::Core::Bundle;
 
 use Treex::PML;
 Treex::PML::UseBackends('PMLBackend');
-Treex::PML::AddResourcePath( Treex::Core::Config->pml_schema_dir() );
+Treex::PML::AddResourcePath( Treex::Core::Config::pml_schema_dir() );
 
-with 'Treex::Core::WildAttr';
-
-use Scalar::Util qw( weaken reftype );
-
-use PerlIO::via::gzip;
-use Storable;
+use Scalar::Util qw( weaken );
 
 has loaded_from => ( is => 'rw', isa => 'Str', default => '' );
 has path        => ( is => 'rw', isa => 'Str' );
 has file_stem   => ( is => 'rw', isa => 'Str', default => 'noname' );
 has file_number => ( is => 'rw', isa => 'Str', builder => 'build_file_number' );
-has compress => ( is => 'rw', isa => 'Bool', default => undef, documentation => 'compression to .gz' );
-has storable => (
-    is            => 'rw',
-    isa           => 'Bool',
-    default       => undef,
-    documentation => 'using Storable with gz compression instead of Treex::PML'
-);
 
 has _pmldoc => (
     isa      => 'Treex::PML::Document',
@@ -40,7 +28,7 @@ has _pmldoc => (
     handles  => {
         set_filename => 'changeFilename',
         map { $_ => $_ }
-            qw( clone writeFile writeTo filename URL
+            qw( load clone save writeFile writeTo filename URL
             changeFilename changeURL fileFormat changeFileFormat
             backend changeBackend encoding changeEncoding userData
             changeUserData metaData changeMetaData listMetaData
@@ -53,7 +41,7 @@ has _pmldoc => (
             hint changeHint pattern_count pattern patterns
             changePatterns tail changeTail
 
-            trees changeTrees treeList tree delete_tree lastTreeNo notSaved
+            trees changeTrees treeList tree lastTreeNo notSaved
             currentTreeNo currentNode nodes value_line value_line_list
             determine_node_type )
     },
@@ -65,11 +53,6 @@ has _index => (
     default => sub { return {} },
 );
 
-has _backref => (
-    is => 'rw',
-    default => sub { return {} },
-);
-
 has _latest_node_number => (    # for generating document-unique IDs
     is      => 'rw',
     default => 0,
@@ -103,9 +86,11 @@ sub build_file_number {
 
 # Full filename without the extension
 sub full_filename {
-    log_fatal 'Incorrect number of arguments' if @_ != 1;
     my $self = shift;
-    return ( $self->path ? $self->path . "/" : '' ) . $self->file_stem . $self->file_number;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
+    return ( $self->path ? $self->path : '' ) . $self->file_stem . $self->file_number;
 }
 
 sub BUILD {
@@ -122,22 +107,7 @@ sub BUILD {
 
         # loading Treex::Core::Document from a file
         elsif ( $params_rf->{filename} ) {
-
-            if ( $params_rf->{filename} =~ /.streex$/ ) {
-                log_fatal 'Storable (.streex) docs must be retrieved by Treex::Core::Document->retrieve_storable($filename)';
-            }
-
-            else {
-
-                # If the file contains invalid PML (e.g. unknown afun value)
-                # Treex::PML fails with die.
-                # TODO: we should rather catch the die message and report it via log_fatal
-                $pmldoc = eval {
-                    $factory->createDocumentFromFile( $params_rf->{filename} );
-                };
-                log_fatal "Error while loading " . $params_rf->{filename} . ($@ ? "\n$@" : '')
-                    if !defined $pmldoc;
-            }
+            $pmldoc = $factory->createDocumentFromFile( $params_rf->{filename} );
         }
     }
 
@@ -156,17 +126,6 @@ sub BUILD {
         }
         $self->_rebless_and_index();
     }
-
-    $self->deserialize_wild;
-    foreach my $bundle ( $self->get_bundles ) {
-        $bundle->deserialize_wild;
-        foreach my $bundlezone ( $bundle->get_all_zones ) {
-            foreach my $node ( map { $_->get_descendants( { add_self => 1 } ) } $bundlezone->get_all_trees ) {
-                $node->deserialize_wild;
-            }
-        }
-    }
-
     return;
 }
 
@@ -174,7 +133,6 @@ sub _rebless_and_index {
     my $self = shift;
     foreach my $bundle ( $self->get_bundles ) {
         bless $bundle, 'Treex::Core::Bundle';
-
         $bundle->_set_document($self);
 
         if ( defined $bundle->{zones} ) {
@@ -198,26 +156,41 @@ sub _rebless_and_index {
                     }
                     $tree->_set_zone($zone);
                 }
+
+                # TODO: Backward links from a-nodes to n-nodes
+                # should be created in n-nodes' constructors,
+                # which must be called after constructing a-nodes.
+                # TODO: Now, we don't call node constructors at all
+                # during loading, we just re-bless Treex::PML::Nodes.
+                if ( $zone->has_ntree ) {
+                    foreach my $nnode ( $zone->get_ntree()->get_descendants() ) {
+                        foreach my $anode ( $nnode->get_anodes() ) {
+                            $anode->_set_n_node($nnode);
+                        }
+                    }
+                }
             }
         }
     }
-    return;
 }
 
 sub _pml_attribute_hash {
     my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
     return $self->metaData('pml_root')->{meta};
 }
 
 #my $_treex_schema_file = Treex::PML::ResolvePath( '.', 'treex_schema.xml', 1 );
-my $_treex_schema_file = Treex::Core::Config->pml_schema_dir . "/" . 'treex_schema.xml';
+my $_treex_schema_file = Treex::Core::Config::pml_schema_dir . "/" . 'treex_schema.xml';
 if ( not -f $_treex_schema_file ) {
     log_fatal "Can't find PML schema $_treex_schema_file";
 }
 
 my $_treex_schema = Treex::PML::Schema->new( { filename => $_treex_schema_file } );
 
-sub _create_empty_pml_doc {    ## no critic (ProhibitUnusedPrivateSubroutines)
+sub _create_empty_pml_doc { ## no critic (ProhibitUnusedPrivateSubroutines)
     my $fsfile = Treex::PML::Document->create
         (
         name => "x",                         #$filename,  ???
@@ -243,18 +216,13 @@ sub index_node_by_id {
     my $self = shift;
     my ( $id, $node ) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::Id' },
+        { isa => 'Id' },
         { isa => 'Maybe[Treex::Core::Node]' },    #jde to takhle?
     );
     my $index = $self->_index;
     if ( defined $node ) {
         $index->{$id} = $node;
         weaken $index->{$id};
-
-        my $refs = $node->_get_referenced_ids;
-        foreach my $type ( keys %{$refs} ) {
-            $self->index_backref( $type, $id, $refs->{$type} );
-        }
     }
     else {
         delete $index->{$id};
@@ -262,87 +230,22 @@ sub index_node_by_id {
     return;
 }
 
-# Add references to the reversed references list
-sub index_backref {
-    my ( $self, $type, $source, $targets ) = @_;
-    my $backref = $self->_backref;
-
-    foreach my $target ( @{$targets} ) {
-        next if ( !defined($target) );
-        my $target_backrefs = $backref->{$target} // {};
-        $backref->{$target} = $target_backrefs;
-
-        $target_backrefs->{$type} = [] if ( !$target_backrefs->{$type} );
-        push @{ $target_backrefs->{$type} }, $source;
-    }
-    return;
-}
-
-# Remove references from the reversed references list
-sub remove_backref {
-    my ( $self, $type, $source, $targets ) = @_;
-    my $backref = $self->_backref;
-
-    foreach my $target ( @{$targets} ) {
-        next if ( !defined($target) );
-        my $target_backrefs = $backref->{$target};
-        next if ( !$target_backrefs );
-
-        $target_backrefs->{$type} = [ grep { $_ ne $source } @{ $target_backrefs->{$type} } ];
-    }
-    return;
-}
-
-# Return a hash of references ( type->[nodes] ) leading to the node with the given id
-sub get_references_to_id {
-    my ( $self, $id ) = @_;
-    my $backref = $self->_backref;
-
-    return if ( !$backref->{$id} );
-    return $backref->{$id};    # TODO clone ?
-}
-
-# Remove all references and backreferences leading to the $node (calls remove_reference() on the source nodes)
-sub _remove_references_to_node {
-    my ( $self, $node ) = @_;
-    my $id      = $node->id;
-    my $backref = $self->_backref;
-
-    # First, delete backreferences to the $node
-    my $refs = $node->_get_referenced_ids();
-    foreach my $type ( keys %{$refs} ) {
-        $self->remove_backref( $type, $id, $refs->{$type} );
-    }
-
-    # Second, delete references to the $node
-    return if ( !$backref->{$id} );
-    my $node_backref = $backref->{$id};
-
-    foreach my $type ( keys %{$node_backref} ) {
-        foreach my $source ( @{ $node_backref->{$type} } ) {
-            $self->get_node_by_id($source)->remove_reference( $type, $id );
-        }
-    }
-
-    # Third, delete backreferences from the $node
-    delete $backref->{$id};
-    return;
-}
-
 sub id_is_indexed {
     my $self = shift;
     my ($id) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::Id' },
+        { isa => 'Id' },
     );
     return ( defined $self->_index->{$id} );
 }
 
 sub get_node_by_id {
+
+    #komentare se vztahuji k TectoMT a vztahu M a A vrstvy -> neni to uz vyresene jinak?
     my $self = shift;
     my ($id) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::Id' },
+        { isa => 'Id' },
     );
     if ( defined $self->_index->{$id} ) {
         return $self->_index->{$id};
@@ -364,21 +267,28 @@ sub get_node_by_id {
 }
 
 sub get_all_node_ids {
-    log_fatal('Incorrect number of arguments') if @_ != 1;
     my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
     return ( keys %{ $self->_index } );
 }
 
 # ----------------- ACCESS TO BUNDLES ----------------------
 
 sub get_bundles {
-    log_fatal('Incorrect number of arguments') if @_ != 1;
     my $self = shift;
+    if ($Treex::Core::Config::params_validate) {    ## no critic (ProhibitPackageVars)
+        pos_validated_list( \@_ );
+    }
     return $self->trees;
 }
 
 sub create_bundle {
     my ( $self, $arg_ref ) = @_;
+
+    #    pos_validated_list( \@_ );
+
     my $fsfile = $self->_pmldoc();
     my $new_bundle;
     my $position_of_new;
@@ -406,13 +316,22 @@ sub create_bundle {
 # -------------- ACCESS TO ZONES ---------------------------------------
 
 sub create_zone {
+
+    #Now it doesn't support compound Zone selector as Scs
     my $self = shift;
     my ( $language, $selector ) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::LangCode' },
-        { isa => 'Treex::Type::Selector', default => '' },
+        { isa => 'LangCode' },
+        { isa => 'Selector', default => '' },
     );
 
+    #my ( $self, $language, $selector ) = @_;
+    #
+    #if ( $language =~ /(.+)(..)/ ) {
+    #    $language = $2;
+    #    $selector = $1;
+    #}
+
     my $new_zone = Treex::Core::DocZone->new(
         {
             'language' => $language,
@@ -434,13 +353,22 @@ sub create_zone {
 }
 
 sub get_zone {
+
+    #Now it doesn't support compound Zone selector as Scs
     my $self = shift;
     my ( $language, $selector ) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::LangCode' },
-        { isa => 'Treex::Type::Selector', default => '' },
+        { isa => 'LangCode' },
+        { isa => 'Selector', default => '' },
     );
 
+    #my ( $self, $language, $selector ) = @_;
+
+    #if ( $language =~ /(.+)(..)/ ) {    # temporarily expecting just two-letter language codes !!!
+    #    $language = $2;
+    #    $selector = $1;
+    #}
+
     my $meta = $self->metaData('pml_root')->{meta};
     if ( defined $meta->{zones} ) {
         foreach my $element ( $meta->{zones}->elements ) {
@@ -457,8 +385,8 @@ sub get_or_create_zone {
     my $self = shift;
     my ( $language, $selector ) = pos_validated_list(
         \@_,
-        { isa => 'Treex::Type::LangCode' },
-        { isa => 'Treex::Type::Selector', default => '' },
+        { isa => 'LangCode' },
+        { isa => 'Selector', default => '' },
     );
 
     my $fs_zone = $self->get_zone( $language, $selector );
@@ -468,83 +396,6 @@ sub get_or_create_zone {
     return $fs_zone;
 }
 
-# -------------- LOADING AND SAVING ---------------------------------------
-
-sub load {
-    my $self = shift;
-    return $self->_pmldoc->load(@_);
-
-    # TODO: this is unfinished: should be somehow connected with the code in BUILD
-}
-
-sub save {
-    my $self = shift;
-    my ($filename) = @_;
-
-    if ( $filename =~ /\.streex$/ ) {
-        open( my $F, ">:via(gzip)", $filename ) or log_fatal $!;
-        print $F Storable::nfreeze( $self );
-        close $F;
-        # using  Storable::nstore_fd($self,*$F) emits 'Inappropriate ioctl for device'
-    }
-
-    else {
-        $self->_serialize_all_wild();
-        return $self->_pmldoc->save(@_);
-    }
-
-    return;
-}
-
-sub _serialize_all_wild {
-    my ($self) = @_;
-    $self->serialize_wild;
-    foreach my $bundle ( $self->get_bundles ) {
-        $bundle->serialize_wild;
-        foreach my $bundlezone ( $bundle->get_all_zones ) {
-            foreach my $node ( map { $_->get_descendants( { add_self => 1 } ) } $bundlezone->get_all_trees ) {
-                $node->serialize_wild;
-            }
-        }
-    }
-    return;
-}
-
-sub retrieve_storable {
-    my ( $class, $file ) = @_;    # $file stands for a file name, but it can be also file handle (needed by the TrEd backend for .streex)
-
-    my $FILEHANDLE;
-
-    my $stringified_doc;
-
-    if ( ref($file) and reftype($file) eq 'GLOB' ) {
-        $FILEHANDLE = $file;
-    }
-    else {
-        log_fatal "filename=$file, but Treex::Core::Document->retrieve(\$filename) can be used only for .streex files"
-            unless $file =~ /\.streex$/;
-        open $FILEHANDLE, "<:via(gzip)", $file or log_fatal($!);
-    }
-
-    my $serialized;
-    # reading it this way is silly, but both slurping the file or
-    #  using Storable::retrieve_fd lead to errors when used with via(gzip)
-    while (<$FILEHANDLE>) {
-        $serialized .= $_;
-    }
-    # my $retrieved_doc = Storable::retrieve_fd(*$FILEHANDLE) or log_fatal($!);
-    my $retrieved_doc = Storable::thaw( $serialized ) or log_fatal $!;
-
-    if ( not ref($file) ) {
-        $retrieved_doc->set_loaded_from($file);
-        my ( $volume, $dirs, $file ) = File::Spec->splitpath($file);
-        $retrieved_doc->set_path($volume . $dirs);
-        # $retrieved_doc->changeFilename($file); # why this doesn't affect the name displayed in TrEd?
-    }
-
-    return $retrieved_doc;
-}
-
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -563,7 +414,7 @@ Treex::Core::Document - representation of a text and its linguistic analyses in
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 DESCRIPTION
 
@@ -574,7 +425,7 @@ can be attached to a document as a whole.
 
 =head1 ATTRIBUTES
 
-C<Treex::Core::Document>'s instances have the following attributes:
+Treex::Core::Document's instances have the following attributes:
 
 =over 4
 
@@ -594,7 +445,7 @@ Textual description of the file's content that is stored in the file.
 
 The attributes can be accessed using semi-affordance accessors:
 getters have the same names as attributes, while setters start with
-C<set_>. For example, the attribute C<path> has a getter C<path()> and a setter C<set_path($path)>
+'set_'. For example by getter C<path()> and setter C<set_path($path)>
 
 
 
@@ -610,18 +461,18 @@ creates a new empty document object.
 
 =item  my $new_document = Treex::Core::Document->new( { pmldoc => $pmldoc } );
 
-creates a C<Treex::Core::Document> instance from an already existing L<Treex::PML::Document> instance
+creates a Treex::Core::Document instance from an already existing Treex::PML::Document instance
 
 =item  my $new_document = Treex::Core::Document->new( { filename => $filename } );
 
-loads a C<Treex::Core::Document> instance from a .treex file
+loads a Treex::Core::Document instance from a .treex file
 
 =back
 
 
 =head2 Access to zones
 
-Document zones are instances of L<Treex::Core::DocZone>, parametrized
+Document zones are instances of Treex::Core::DocZone, parametrized
 by language code and possibly also by another free label
 called selector, whose purpose is to distinguish zones for the same language
 but from a different source.
@@ -668,17 +519,17 @@ after the existing bundle.
 
 =over 4
 
-=item $document->index_node_by_id( $id, $node );
+=item  $document->index_node_by_id( $id, $node );
 
-The node is added to the document's indexing table C<id2node> (it is done
-automatically in L<Treex::Core::Node::set_attr()|Treex::Core::Node/set_attr>
-if the attribute name is 'C<id>'). When using C<undef> in the place of the
-second argument, the entry for the given id is deleted from the hash.
+The node is added to the id2node hash table (as mentioned above, it
+is done automatically in $node->set_attr() if the attribute name
+is 'id'). When using undef in the place of the second argument, the entry
+for the given id is deleted from the hash.
 
 
 =item my $node = $document->get_node_by_id( $id );
 
-Return the node which has the value C<$id> in its 'C<id>' attribute,
+Return the node which has the value $id in its 'id' attribute,
 no matter to which tree and to which bundle in the given document
 the node belongs to.
 
@@ -688,41 +539,14 @@ documents differently or hack it by dropping the problematic links.
 
 =item $document->id_is_indexed( $id );
 
-Return C<true> if the given C<id> is already present in the indexing table.
+Return true if the given id is already present in the indexing table.
 
 =item $document->get_all_node_ids();
 
 Return the array of all node identifiers indexed in the document.
 
-=item $document->get_references_to_id( $id );
-
-Return all references leading to the given node id in a hash (keys are reference types, e.g. 'alignment',
-'a/lex.rf' etc., values are arrays of nodes referencing this node).
-
-=item $document->remove_refences_to_id( $id );
-
-Remove all references to the given node id (calls remove_reference() on each referencing node).
-
 =back
 
-=head2 Serializing
-
-=over 4 
-
-=item my $document = load($filename, \%opts)
-
-Loads document from C<$filename> given C<%opts> using L<Treex::PML::Document::load()>
-
-=item $document->save($filename)
-
-Saves document to C<$filename> using L<Treex::PML::Document::save()>,
-or by the Storable module if the file's extension is .streex.gz.
-
-=item Treex::Core::Document->retrieve_storable($filename)
-
-Loading a document from the .streex (Storable) format.
-
-=back
 
 =head2 Other
 
@@ -741,10 +565,8 @@ Zdeněk Žabokrtský <zabokrtsky@ufal.mff.cuni.cz>
 
 Martin Popel <popel@ufal.mff.cuni.cz>
 
-Ondřej Dušek <odusek@ufal.mff.cuni.cz>
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2011-2012 by Institute of Formal and Applied Linguistics, Charles University in Prague
+Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
