@@ -1,12 +1,9 @@
 package Treex::Core::DocumentReader;
-{
-  $Treex::Core::DocumentReader::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::DocumentReader::VERSION = '0.05222';
 }
 use Moose::Role;
 
-# with Moose >= 2.00, this must be present also in roles
-use MooseX::SemiAffordanceAccessor 0.09;
-
 requires 'next_document';
 
 requires 'number_of_documents';
@@ -61,7 +58,7 @@ sub next_document_for_this_job {
     # Regarding  perlcritic ProtectPrivateSubs:
     # I consider _redirect_output as internal for Treex::Core modules.
     if ( $doc && $self->jobindex ) {
-        Treex::Core::Run::_redirect_output( $self->outdir, $self->doc_number, $self->jobindex );    ## no critic (ProtectPrivateSubs)
+        Treex::Core::Run::_redirect_output( $self->outdir, $self->doc_number, $self->jobindex ); ## no critic (ProtectPrivateSubs)
     }
 
     return $doc;
@@ -94,12 +91,12 @@ Treex::Core::DocumentReader - interface for all document readers
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 DESCRIPTION
 
 Document readers are a Treex concept how to load documents to be processed by Treex.
-The documents can be stored in files (in various formats) or read from C<STDIN>
+The documents can be stored in files (in various formats) or read from STDIN
 or retrieved from a socket etc.
 
 =head1 METHODS
@@ -117,7 +114,7 @@ Return next document (L<Treex::Core::Document>).
 =item number_of_documents
 
 Total number of documents that will be produced by this reader.
-If the number is unknown in advance, C<undef> should be returned.
+If the number is unknown in advance, undef should be returned.
 
 =back
 
@@ -127,22 +124,22 @@ If the number is unknown in advance, C<undef> should be returned.
 
 =item is_current_document_for_this_job
 
-Is the document that was most recently returned by C<$self->next_document()>
-supposed to be processed by this job?
+Is the document that was most recently returned by $self->next_document()
+supossed to be processed by this job?
 Job indices and document numbers are 1-based, so e.g. for
-C<jobs = 5, jobindex = 3> we want to load documents with numbers 3,8,13,18,...
-C<jobs = 5, jobindex = 5> we want to load documents with numbers 5,10,15,20,...
-i.e. those documents where C<(doc_number-1) % jobs == (jobindex-1)>.
+ jobs = 5, jobindex = 3 we want to load documents with numbers 3,8,13,18,...
+ jobs = 5, jobindex = 5 we want to load documents with numbers 5,10,15,20,...
+i.e. those documents where (doc_number-1) % jobs == (jobindex-1).
 
 =item next_document_for_this_job
 
 Returns a next document which should be processed by this job.
-If C<jobindex> is set, returns "modulo number of jobs".
+If jobindex is set, returns "modulo number of jobs".
 See C<is_current_document_for_this_job>.
 
 =item number_of_documents_per_this_job
 
-Total number of documents that will be produced by this reader for this job.
+Total number of documents that will be produiced by this reader for this job.
 It's computed based on C<number_of_documents>, C<jobindex> and C<jobs>.
 
 =item restart
@@ -153,7 +150,7 @@ You can add additional behavior using the Moose C<after 'restart'> construct.
 
 =back
 
-=head1 SEE ALSO
+=head1 SEE
 
 L<Treex::Block::Read::Sentences>
 L<Treex::Block::Read::Text>
@@ -168,4 +165,4 @@ Martin Popel <popel@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
