@@ -1,11 +1,10 @@
 package Treex::Core::Log;
-{
-  $Treex::Core::Log::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::Log::VERSION = '0.05222';
 }
 use strict;
 use warnings;
 
-use 5.008;
 use utf8;
 use English '-no_match_vars';
 
@@ -20,8 +19,8 @@ our @EXPORT = qw(log_fatal log_warn log_info log_debug log_memory);    ## no cri
 
 $Carp::CarpLevel = 1;
 
-binmode STDOUT, ":encoding(utf-8)";
-binmode STDERR, ":encoding(utf-8)";
+binmode STDOUT, ":utf8";
+binmode STDERR, ":utf8";
 
 # Autoflush after every Perl statement should enforce that INFO and FATALs are ordered correctly.
 {
@@ -32,18 +31,13 @@ binmode STDERR, ":encoding(utf-8)";
     *STDERR->autoflush();
 }
 
-
-my @ERROR_LEVEL_NAMES = qw(ALL DEBUG INFO WARN FATAL);
-Readonly my %ERROR_LEVEL_VALUE => map {$ERROR_LEVEL_NAMES[$_] => $_} (0 .. $#ERROR_LEVEL_NAMES);
-
-#Readonly my %ERROR_LEVEL_VALUE => (
-#    'ALL'   => 0,
-#    'DEBUG' => 1,
-#    'INFO'  => 2,
-#    'WARN'  => 3,
-#    'FATAL' => 4,
-#);
-
+Readonly my %ERROR_LEVEL_VALUE => (
+    'ALL'   => 0,
+    'DEBUG' => 1,
+    'INFO'  => 2,
+    'WARN'  => 3,
+    'FATAL' => 4,
+);
 
 use Moose::Util::TypeConstraints;
 enum 'ErrorLevel' => keys %ERROR_LEVEL_VALUE;
@@ -67,7 +61,7 @@ sub log_set_error_level {
 }
 
 sub get_error_level {
-    return $ERROR_LEVEL_NAMES[$current_error_level_value];
+    return $current_error_level_value;
 }
 
 # fatal error messages can't be suppressed
@@ -78,13 +72,11 @@ sub log_fatal {
         $unfinished_line = 0;
     }
     my $line = "TREEX-FATAL:\t$message\n\n";
-    if ( $current_error_level_value <= $ERROR_LEVEL_VALUE{'DEBUG'} ) {
-        if ($OS_ERROR) {
-            $line .= "PERL ERROR MESSAGE: $OS_ERROR\n";
-        }
-        if ($EVAL_ERROR) {
-            $line .= "PERL EVAL ERROR MESSAGE: $EVAL_ERROR\n";
-        }
+    if ($OS_ERROR) {
+        $line .= "PERL ERROR MESSAGE: $OS_ERROR\n";
+    }
+    if ($EVAL_ERROR) {
+        $line .= "PERL EVAL ERROR MESSAGE: $EVAL_ERROR\n";
     }
     $line .= "PERL STACK:";
     cluck $line;
@@ -209,7 +201,7 @@ Treex::Core::Log - logger tailored for the needs of Treex
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 SYNOPSIS
 
@@ -233,13 +225,13 @@ version 0.08633_1
 
 =head1 DESCRIPTION
 
-C<Treex::Core::Log> is a logger developed with the Treex system.
+Treex::Core::Log is a logger developed with the Treex system.
 It uses more or less standard leveled set of reporting functions,
-printing the messages at C<STDERR>.
+printing the messages at STDERR.
 
 
 Note that this module might be completely substituted
-by more elaborate solutions such as L<Log::Log4perl> in the
+by more elaborate solutions such as Log::Log4perl in the
 whole Treex in the future
 
 
@@ -342,4 +334,4 @@ Zdeněk Žabokrtský <zabokrtsky@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
