@@ -1,44 +1,14 @@
 package Treex::Core::Node;
-{
-  $Treex::Core::Node::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::Node::VERSION = '0.05222';
 }
-
-use namespace::autoclean;
-
 use Moose;
 use MooseX::NonMoose;
 use Treex::Core::Common;
 use Cwd;
-use Scalar::Util qw(refaddr);
 use Treex::PML;
 
 extends 'Treex::PML::Node';
-with 'Treex::Core::WildAttr';
-
-# overloading does not work with namespace::autoclean
-# see https://rt.cpan.org/Public/Bug/Display.html?id=50938
-# We may want to use https://metacpan.org/module/namespace::sweep instead.
-#
-# use overload
-#     '""' => 'to_string',
-#     '==' => 'equals',
-#     '!=' => '_not_equals',
-#     'eq' => 'equals',      # deprecated
-#     'ne' => '_not_equals', # deprecated
-#     'bool' => sub{1},
-#
-#     # We can A) let Magic Autogeneration to build "derived" overloadings,
-#     # or B) we can disable this feature (via fallback=>0)
-#     # and define only the needed overloadings
-#     # (so all other overloadings will result in fatal errors).
-#     # See perldoc overload.
-#     # I decided for A, but uncommenting the following lines can catch some misuses.
-#     #'!'  => sub{0},
-#     #'.' => sub{$_[2] ? $_[1] . $_[0]->to_string : $_[0]->to_string . $_[1]},
-#     #fallback => 0,
-# ;
-# # TODO: '<' => 'precedes' (or better '<=>' => ...)
-# # 'eq' => sub {log_warn 'You should use ==' && return $_[0]==$_[1]} # similarly for 'ne'
 
 Readonly my $_SWITCHES_REGEX => qr/^(ordered|add_self|(preceding|following|first|last)_only)$/x;
 my $CHECK_FOR_CYCLES = 1;
@@ -57,11 +27,7 @@ has id => (
 
 sub BUILD {
     my ( $self, $arg_ref ) = @_;
-
-    if (( not defined $arg_ref or not defined $arg_ref->{_called_from_core_} )
-        and not $Treex::Core::Config::running_in_tred
-        )
-    {
+    if ( not defined $arg_ref or not defined $arg_ref->{_called_from_core_} ) {
         log_fatal 'Because of node indexing, no nodes can be created outside of documents. '
             . 'You have to use $zone->create_tree(...) or $node->create_child() '
             . 'instead of Treex::Core::Node...->new().';
@@ -69,24 +35,6 @@ sub BUILD {
     return;
 }
 
-sub to_string {
-    my ($self) = @_;
-    return $self->id // 'node_without_id(addr=' . refaddr($self) . ')';
-}
-
-# Since we have overloaded stringification, we must overload == as well,
-# so you can use "if ($nodeA ==  $nodeB){...}".
-sub equals {
-    my ($self, $node) = @_;
-    #return ref($node) && $node->id eq $self->id;
-    return ref($node) && refaddr($node) == refaddr($self);
-}
-
-sub _not_equals {
-    my ($self, $node) = @_;
-    return !$self->equals($node);
-}
-
 sub _index_my_id {
     my $self = shift;
     pos_validated_list( \@_, { isa => 'Any', optional => 1 } );    #TODO
@@ -96,26 +44,25 @@ sub _index_my_id {
 
 # ---- access to attributes ----
 
-# unlike attr (implemented in Treex::PML::Instance::get_data)
-# get_attr implements only "plain" and "nested hash" attribute names,
-# i.e. no XPath-like expressions (a/aux.rf[3]) are allowed.
-# This results in much faster code.
+sub _pml_attribute_hash {
+    log_fatal 'Incorrect number of arguments' if @_ != 1;
+    my $self = shift;
+    return $self;
+}
+
 sub get_attr {
     my ( $self, $attr_name ) = @_;
     log_fatal('Incorrect number of arguments') if @_ != 2;
-    my $val = $self;
-    for my $step ( split /\//, $attr_name ) {
-        if ( !defined $val ) {
-            log_fatal "Attribute '$attr_name' contains strange symbols."
-                . " For XPath like constructs (e.g. 'a/aux.rf[3]') use the 'attr' method."
-                if $attr_name =~ /[^-\w\/.]/;
-        }
-        $val = $val->{$step};
-    }
-    return $val;
-}
 
-use Treex::PML::Factory;
+    #simple attributes can be accessed directly
+    if ( $attr_name =~ /^[\w\.]+$/ ) {
+        return $self->{$attr_name};
+    }
+    else {
+        my $attr_hash = $self->_pml_attribute_hash();
+        return $attr_hash->attr($attr_name);
+    }
+}
 
 sub set_attr {
     my ( $self, $attr_name, $attr_value ) = @_;
@@ -130,52 +77,19 @@ sub set_attr {
         $attr_value = Treex::PML::List->new( @{$attr_value} );
     }
 
-    if ($attr_name =~ /\.rf$/){
-        my $document = $self->get_document();
-
-        # Delete previous back references
-        my $old_value = $self->get_attr($attr_name);
-        if ($old_value) {
-            if ( ref $old_value eq 'Treex::PML::List' && @$old_value ) {
-                $document->remove_backref( $attr_name, $self->id, $old_value );
-            }
-            else {
-                $document->remove_backref( $attr_name, $self->id, [$old_value] );
-            }
-        }
-
-        # Set new back references
-        my $ids = ref($attr_value) eq 'Treex::PML::List' ? $attr_value : [$attr_value];
-        $document->index_backref( $attr_name, $self->id, $ids );
-    }
-
     #simple attributes can be accessed directly
-    return $self->{$attr_name} = $attr_value if $attr_name =~ /^[\w\.]+$/;
-    log_fatal "Attribute '$attr_name' contains strange symbols."
-        . " No XPath like constructs (e.g. 'a/aux.rf[3]') are allowed."
-        if $attr_name =~ /[^-\w\/.]/;
-
-    my $val = $self;
-    my @steps = split /\//, $attr_name;
-    while (1) {
-        my $step = shift @steps;
-        if (@steps) {
-            if ( !defined( $val->{$step} ) ) {
-                $val->{$step} = Treex::PML::Factory->createStructure();
-            }
-            $val = $val->{$step};
-        }
-        else {
-            return $val->{$step} = $attr_value;
-        }
+    if ( $attr_name =~ /^[\w\.]+$/ ) {
+        return $self->{$attr_name} = $attr_value;
+    }
+    else {
+        return Treex::PML::Node::set_attr( $self, $attr_name, $attr_value );    # better to find superclass, but speed?
     }
-    return;
 }
 
 sub get_deref_attr {
     my ( $self, $attr_name ) = @_;
     log_fatal('Incorrect number of arguments') if @_ != 2;
-    my $attr_value = $self->get_attr($attr_name);
+    my $attr_value = $self->_pml_attribute_hash()->attr($attr_name);
 
     return if !$attr_value;
     my $document = $self->get_document();
@@ -187,23 +101,66 @@ sub get_deref_attr {
 sub set_deref_attr {
     my ( $self, $attr_name, $attr_value ) = @_;
     log_fatal('Incorrect number of arguments') if @_ != 3;
-
-    # If $attr_value is an array of nodes
     if ( ref($attr_value) eq 'ARRAY' ) {
-        my @list = map { $_->id } @{$attr_value};
+        my @list = map { $_->get_attr('id') } @{$attr_value};
         $attr_value = Treex::PML::List->new(@list);
     }
-
-    # If $attr_value is just one node
     else {
-        $attr_value = $attr_value->id;
+        $attr_value = $attr_value->get_attr('id');
     }
 
-    # Set the new reference(s)
-    $self->set_attr( $attr_name, $attr_value );
-    return;
+    # attr setting always through TectoMT set_attr, as it can be overidden (and it is in Node/N.pm)
+    #return $fsnode{ ident $self}->set_attr( $attr_name, $attr_value );
+    return $self->set_attr( $attr_name, $attr_value );
 }
 
+##-- begin proposal
+# Example usage:
+# Treex::Core::Node::T methods get_lex_anode and get_aux_anodes could use:
+# my $a_lex = $t_node->get_r_attr('a/lex.rf'); # returns the node or undef
+# my @a_aux = $t_node->get_r_attr('a/aux.rf'); # returns the nodes or ()
+sub get_r_attr {
+    my ( $self, $attr_name ) = @_;
+    log_fatal('Incorrect number of arguments') if @_ != 2;
+    my $attr_value = $self->_pml_attribute_hash()->attr($attr_name);
+
+    return if !$attr_value;
+    my $document = $self->get_document();
+    if (wantarray) {
+        log_fatal("Attribute '$attr_name' is not a list, but get_r_attr() called in a list context.")
+            if ref($attr_value) ne 'Treex::PML::List';
+        return map { $document->get_node_by_id($_) } @{$attr_value};
+    }
+
+    log_fatal("Attribute $attr_name is a list, but get_r_attr() not called in a list context.")
+        if ref($attr_value) eq 'Treex::PML::List';
+    return $document->get_node_by_id($attr_value);
+}
+
+# Example usage:
+# $t_node->set_r_attr('a/lex.rf', $a_lex);
+# $t_node->set_r_attr('a/aux.rf', @a_aux);
+sub set_r_attr {
+    my ( $self, $attr_name, @attr_values ) = @_;
+    log_fatal('Incorrect number of arguments') if @_ < 3;
+    my $fs = $self->_pml_attribute_hash();
+
+    # TODO $fs->type nefunguje - asi protoze se v konstruktorech nenastavuje typ
+    if ( $fs->type($attr_name) eq 'Treex::PML::List' ) {
+        my @list = map { $_->get_attr('id') } @attr_values;
+
+        # TODO: overriden Node::N::set_attr is bypassed by this call
+        return $fs->set_attr( $attr_name, Treex::PML::List->new(@list) );
+    }
+    log_fatal("Attribute '$attr_name' is not a list, but set_r_attr() called with @attr_values values.")
+        if @attr_values > 1;
+
+    # TODO: overriden Node::N::set_attr is bypassed by this call
+    return $fs->set_attr( $attr_name, $attr_values[0]->get_attr('id') );
+}
+
+# ---------------------
+
 sub get_bundle {
     log_fatal 'Incorrect number of arguments' if @_ != 1;
     my $self = shift;
@@ -222,11 +179,7 @@ sub get_zone {
         $zone = $self->get_root->_get_zone;    ## no critic (ProtectPrivateSubs)
     }
 
-    if (!$zone) {
-#        $self->get_document->save("pokus2.treex.gz");
-    }
-
-    log_fatal "a node (" . $self->id . ") can't reveal its zone" if !$zone;
+    log_fatal "a node can't reveal its zone" if !$zone;
     return $zone;
 
 }
@@ -242,10 +195,8 @@ sub remove {
     my $document = $self->get_document();
 
     # Remove the subtree from the document's indexing table
-    my @to_remove = ( $self, $self->get_descendants );
-    foreach my $node ( @to_remove) {
+    foreach my $node ( $self, $self->get_descendants ) {
         if ( defined $node->id ) {
-            $document->_remove_references_to_node( $node );
             $document->index_node_by_id( $node->id, undef );
         }
     }
@@ -260,49 +211,7 @@ sub remove {
 
     # By reblessing we make sure that
     # all methods called on removed nodes will result in fatal errors.
-    foreach my $node (@to_remove){
-        bless $node, 'Treex::Core::Node::Deleted';
-    }
-    return;
-}
-
-# Return all nodes that have a reference of the given type (e.g. 'alignment', 'a/lex.rf') to this node
-sub get_referencing_nodes {
-
-    my ( $self, $type ) = @_;
-    my $doc  = $self->get_document;
-    my $refs = $doc->get_references_to_id( $self->id );
-
-    return if ( !$refs || !$refs->{$type} );
-    return map { $doc->get_node_by_id($_) } @{ $refs->{$type} };
-}
-
-# Remove a reference of the given type to the given node. This will not remove a reverse reference from document
-# index, since it is itself called from when removing reverse references; use the API methods for the individual
-# references if you want to keep reverse references up-to-date.
-sub remove_reference {
-    my ( $self, $type, $id ) = @_;
-
-    if ( $type eq 'alignment' ) {    # handle alignment links separately
-
-        my $links = $self->get_attr('alignment');
-
-        if ($links) {
-            my $document = $self->get_document;
-            $self->set_attr( 'alignment', [ grep { $_->{'counterpart.rf'} ne $id } @{$links} ] );
-        }
-    }
-    else {
-        my $attr = $self->get_attr($type);
-        log_fatal "undefined attr $type (id=$id)" if !defined $attr;
-
-        if ( $attr eq $id || scalar( @{$attr} ) <= 1 ) {                # single-value attributes
-            $self->set_attr( $type, undef );
-        }
-        else {
-            $attr->delete_value($id);                                   # TODO : will it be always a Treex::PML::List? Looks like it works.
-        }
-    }
+    bless $self, 'Treex::Core::Node::Deleted';
     return;
 }
 
@@ -393,8 +302,8 @@ sub get_document {
     log_fatal 'Incorrect number of arguments' if @_ != 1;
     my $self   = shift;
     my $bundle = $self->get_bundle();
-    log_fatal('Cannot call get_document on a node which is in no bundle') if !defined $bundle;
-    return $bundle->get_document();
+    log_fatal('Cannot call get_document on a node which is in no bundle') if not defined $bundle;
+    return $self->get_bundle->get_document();
 }
 
 sub get_root {
@@ -409,12 +318,6 @@ sub is_root {
     return !$self->parent;
 }
 
-sub is_leaf {
-    log_fatal 'Incorrect number of arguments' if @_ != 1;
-    my $self = shift;
-    return not $self->firstson;
-}
-
 sub get_parent {
     log_fatal 'Incorrect number of arguments' if @_ != 1;
     my $self = shift;
@@ -433,9 +336,6 @@ sub set_parent {
     #    log_fatal("Cannot move a node from one document to another");
     #}
 
-    # We cannot detach a node by setting an undefined parent. The if statement below will die.
-    # Let's inform the user where the bad call is.
-    log_fatal( 'Cannot attach the node ' . $self->id . ' to an undefined parent' ) if ( !defined($parent) );
     if ( $self == $parent || $CHECK_FOR_CYCLES && $parent->is_descendant_of($self) ) {
         my $id   = $self->id;
         my $p_id = $parent->id;
@@ -611,24 +511,9 @@ sub get_aligned_nodes {
     return ( undef, undef );
 }
 
-sub get_aligned_nodes_of_type {
-    my ( $self, $type_regex ) = @_;
-    my @nodes;
-    my ( $n_rf, $t_rf ) = $self->get_aligned_nodes();
-    return if !$n_rf;
-    my $iterator = List::MoreUtils::each_arrayref( $n_rf, $t_rf );
-    while ( my ( $node, $type ) = $iterator->() ) {
-        if ( $type =~ /$type_regex/ ) {
-            push @nodes, $node;
-        }
-    }
-    return @nodes;
-}
-
 sub is_aligned_to {
     my ( $self, $node, $type ) = @_;
-    log_fatal 'Incorrect number of parameters' if @_ != 3;
-    return any { $_ eq $node } $self->get_aligned_nodes_of_type( $node, $type ) ? 1 : 0;
+    return grep { $_ eq $node } $self->get_aligned_nodes( $node, $type ) ? 1 : 0;
 }
 
 sub delete_aligned_node {
@@ -636,11 +521,7 @@ sub delete_aligned_node {
     my $links_rf = $self->get_attr('alignment');
     my @links    = ();
     if ($links_rf) {
-        @links = grep {
-            $_->{'counterpart.rf'} ne $node->id
-                || ( defined($type) && defined( $_->{'type'} ) && $_->{'type'} ne $type )
-            }
-            @$links_rf;
+        @links = grep { $_->{'counterpart.rf'} ne $node->id || $_->{'type'} ne $type } @$links_rf;
     }
     $self->set_attr( 'alignment', \@links );
     return;
@@ -655,21 +536,6 @@ sub add_aligned_node {
     return;
 }
 
-# remove invalid alignment links (leading to unindexed nodes)
-sub update_aligned_nodes {
-
-    my ($self)   = @_;
-    my $doc      = $self->get_document();
-    my $links_rf = $self->get_attr('alignment');
-    my @new_links;
-
-    foreach my $link ( @{$links_rf} ) {
-        push @new_links, $link if ( $doc->id_is_indexed( $link->{'counterpart.rf'} ) );
-    }
-    $self->set_attr( 'alignment', \@new_links );
-    return;
-}
-
 #************************************
 #---- OTHER ------
 
@@ -689,29 +555,51 @@ sub get_depth {
 sub _normalize_node_ordering {
 }
 
-sub get_address {
-    log_fatal 'Incorrect number of arguments' if @_ != 1;
-    my $self     = shift;
-    my $id       = $self->id;
-    my $bundle   = $self->get_bundle();
-    my $doc      = $bundle->get_document();
-    my $file     = $doc->loaded_from || ( $doc->full_filename . '.treex' );
-    my $position = $bundle->get_position() + 1;
-
-    #my $filename = Cwd::abs_path($file);
-    return "$file##$position.$id";
-}
-
-# Empty DESTROY method is a hack to get rid of the "Deep recursion warning"
-# in Treex::PML::Node::DESTROY and MooseX::NonMoose::Meta::Role::Class::_check_superclass_destructor.
-# Without this hack, you get the warning after creating a node with 99 or more children.
-# Deep recursion on subroutine "Class::MOP::Method::execute" at .../5.12.2/MooseX/NonMoose/Meta/Role/Class.pm line 183.
-sub DESTROY {
-}
-
 #*************************************
 #---- DEPRECATED & QUESTIONABLE ------
 
+sub disconnect {
+    my $self = shift;
+    log_debug( '$node->disconnect is deprecated, use $node->remove', 1 );
+    return $self->remove();
+}
+
+sub get_ordering_value {
+    my $self = shift;
+    log_warn( '$node->get_ordering_value is deprecated, use $node->ord', 1 );
+    return $self->ord;
+}
+
+sub set_ordering_value {
+    my $self = shift;
+    log_warn( '$node->set_ordering_value($ord) is deprecated, it should be private $node->_set_ord($n)', 1 );
+    my ($val) = pos_validated_list(
+        \@_,
+        { isa => 'Num' },    #or isa => 'Int' ??, or Positive Int?
+    );
+    $self->_set_ord($val);
+    return;
+}
+
+sub get_fposition {
+    log_fatal 'Incorrect number of arguments' if @_ != 1;
+    my $self = shift;
+    my $id   = $self->get_attr('id');
+
+    my $fsfile  = $self->get_document->_get_pmldoc();    ## no critic (ProtectPrivateSubs)
+    my $fs_root = $self->get_bundle;
+
+    my $bundle_number = 1;
+    TREES:
+    foreach my $t ( $fsfile->trees() ) {
+        last TREES if $t == $fs_root;
+        $bundle_number++;
+    }
+
+    my $filename = Cwd::abs_path( $self->get_document->get_fsfile_name() );
+    return "$filename##$bundle_number.$id";
+}
+
 sub generate_new_id {    #TODO move to Core::Document?
     log_fatal 'Incorrect number of arguments' if @_ != 1;
     my $self = shift;
@@ -734,7 +622,7 @@ sub generate_new_id {    #TODO move to Core::Document?
     while (1) {
         $latest_node_number++;
         $new_id = "${id_base}n$latest_node_number";
-        last if !$doc->id_is_indexed($new_id);
+        last if not $doc->id_is_indexed($new_id);
 
     }
 
@@ -788,91 +676,11 @@ sub get_attrs {
     return @attr_values;
 }
 
-# Return all attributes of the given node (sub)type that contain references
-sub _get_reference_attrs {
-    my ($self) = @_;
-    return ();
-}
-
-# Return IDs of all nodes to which there are reference links from this node (must be overridden in
-# the respective node types)
-sub _get_referenced_ids {
-    my ($self) = @_;
-    my $ret = {};
-
-    # handle alignment separately
-    my $links_rf = $self->get_attr('alignment');
-    $ret->{alignment} = [ map { $_->{'counterpart.rf'} } @{$links_rf} ] if ($links_rf);
-
-    # all other references
-    foreach my $ref_attr ( $self->_get_reference_attrs() ) {
-        my $val = $self->get_attr($ref_attr) or next;
-        if ( !ref $val ) {    # single-valued
-            $ret->{$ref_attr} = [$val];
-        }
-        else {
-            $ret->{$ref_attr} = $val;
-        }
-    }
-    return $ret;
-}
-
-
-# ---------------------
-
-# changing the functionality of Treex::PML::Node's following() so that it traverses all
-# nodes in all trees in all zones (needed for search in TrEd)
-
-sub following {
-    my ( $self ) = @_;
-
-    my $pml_following =  Treex::PML::Node::following(@_);
-
-    if ( $pml_following ) {
-        return $pml_following;
-    }
-
-    else {
-        my $bundle =  ( ref($self) eq 'Treex::Core::Bundle' ) ? $self : $self->get_bundle;
-
-        my @all_trees = map {
-            ref($_) ne 'Treex::PML::Struct'
-            ? $_->get_all_trees
-            : ()
-        } $bundle->get_all_zones;
-
-        if ( ref($self) eq 'Treex::Core::Bundle' ) {
-            return $all_trees[0];
-        }
-
-        else {
-            my $my_root = $self->get_root;
-            foreach my $index ( 0..$#all_trees ) {
-                if ( $all_trees[$index] eq $my_root ) {
-                    return $all_trees[$index+1];
-                }
-            }
-            log_fatal "Node belongs to no tree: this should never happen";
-        }
-    }
-}
-
-sub descendants {
-    my ( $self ) = @_;
-    return ( map { $_->_descendants_and_self() } $self->children );
-}
-
-sub _descendants_and_self {
-    my ( $self ) = @_;
-    return ( $self, map { $_->_descendants_and_self() } $self->children );
-}
-
-
 # TODO: How to do this in an elegant way?
 # Unless we find a better way, we must disable two perlcritics
 package Treex::Core::Node::Removed;
-{
-  $Treex::Core::Node::Removed::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::Node::Removed::VERSION = '0.05222';
 }    ## no critic (ProhibitMultiplePackages)
 use Treex::Core::Log;
 
@@ -891,65 +699,18 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
-##-- begin proposal
-# Example usage:
-# Treex::Core::Node::T methods get_lex_anode and get_aux_anodes could use:
-# my $a_lex = $t_node->get_r_attr('a/lex.rf'); # returns the node or undef
-# my @a_aux = $t_node->get_r_attr('a/aux.rf'); # returns the nodes or ()
-sub get_r_attr {
-    my ( $self, $attr_name ) = @_;
-    log_fatal('Incorrect number of arguments') if @_ != 2;
-    my $attr_value = $self->get_attr($attr_name);
-
-    return if !$attr_value;
-    my $document = $self->get_document();
-    if (wantarray) {
-        log_fatal("Attribute '$attr_name' is not a list, but get_r_attr() called in a list context.")
-            if ref($attr_value) ne 'Treex::PML::List';
-        return map { $document->get_node_by_id($_) } @{$attr_value};
-    }
-
-    log_fatal("Attribute $attr_name is a list, but get_r_attr() not called in a list context.")
-        if ref($attr_value) eq 'Treex::PML::List';
-    return $document->get_node_by_id($attr_value);
-}
-
-# Example usage:
-# $t_node->set_r_attr('a/lex.rf', $a_lex);
-# $t_node->set_r_attr('a/aux.rf', @a_aux);
-sub set_r_attr {
-    my ( $self, $attr_name, @attr_values ) = @_;
-    log_fatal('Incorrect number of arguments') if @_ < 3;
-    my $fs = $self;
-
-    # TODO $fs->type nefunguje - asi protoze se v konstruktorech nenastavuje typ
-    if ( $fs->type($attr_name) eq 'Treex::PML::List' ) {
-        my @list = map { $_->id } @attr_values;
-
-        # TODO: overriden Node::N::set_attr is bypassed by this call
-        return $fs->set_attr( $attr_name, Treex::PML::List->new(@list) );
-    }
-    log_fatal("Attribute '$attr_name' is not a list, but set_r_attr() called with @attr_values values.")
-        if @attr_values > 1;
-
-    # TODO: overriden Node::N::set_attr is bypassed by this call
-    return $fs->set_attr( $attr_name, $attr_values[0]->id );
-}
-
-
-
-=for Pod::Coverage BUILD
+=for Pod::Coverage BUILD disconnect get_ordering_value set_ordering_value get_r_attr set_r_attr
 
 
 =encoding utf-8
 
 =head1 NAME
 
-Treex::Core::Node - smallest unit that holds information in Treex
+Treex::Core::Node
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 DESCRIPTION
 
@@ -965,10 +726,10 @@ Tree's attributes must be stored as attributes of the root node.
 
 =over 4
 
-=item  my $new_node = $existing_node->create_child({lemma=>'house', tag=>'NN' });
+=item  my $new_node = $existing_node->create_child(lemma=>'house', tag=>'NN' });
 
 Creates a new node as a child of an existing node. Some of its attribute
-can be filled. Direct calls of node constructors (C<< ->new >>) should be avoided.
+can be filled. Direct calls of node constructors (->new) should be avoided.
 
 
 =back
@@ -981,15 +742,15 @@ can be filled. Direct calls of node constructors (C<< ->new >>) should be avoide
 
 =item my $bundle = $node->get_bundle();
 
-Returns the L<Treex::Core::Bundle> object in which the node's tree is contained.
+Returns the L<Treex::Core::Bundle|Treex::Core::Bundle> object in which the node's tree is contained.
 
 =item my $document = $node->get_document();
 
-Returns the L<Treex::Core::Document> object in which the node's tree is contained.
+Returns the L<Treex::Core::Document|Treex::Core::Document> object in which the node's tree is contained.
 
 =item get_layer
 
-Return the layer of this node (I<a>, I<t>, I<n> or I<p>).
+Return the layer of this node (I<a,t,n or p>).
 
 =item get_zone
 
@@ -998,11 +759,11 @@ Return the zone (L<Treex::Core::BundleZone>) to which this node
 
 =item $lang_code = $node->language
 
-shortcut for C<< $lang_code = $node->get_zone()->language >>
+shortcut for $lang_code = $node->get_zone()->language
 
 =item $selector = $node->selector
 
-shortcut for C<< $selector = $node->get_zone()->selector >>
+shortcut for $selector = $node->get_zone()->selector
 
 =back
 
@@ -1018,9 +779,9 @@ Returns the value of the node attribute of the given name.
 =item my $node->set_attr($name,$value);
 
 Sets the given attribute of the node with the given value.
-If the attribute name is C<id>, then the document's indexing table
-is updated. If value of the type C<List> is to be filled,
-then C<$value> must be a reference to the array of values.
+If the attribute name is 'id', then the document's indexing table
+is updated. If value of the type List is to be filled,
+then $value must be a reference to the array of values.
 
 =item my $node2 = $node1->get_deref_attr($name);
 
@@ -1029,7 +790,7 @@ it returns the appropriate node (or a reference to the list of nodes).
 
 =item my $node1->set_deref_attr($name, $node2);
 
-Sets the given attribute with C<id> (list of C<id>s) of the given node (list of nodes).
+Sets the given attribute with ID (list of IDs) of the given node (list of nodes).
 
 =item my $node->add_to_listattr($name, $value);
 
@@ -1052,15 +813,15 @@ by a C<$value> (typically the value is an empty string).
 
 =item my $parent_node = $node->get_parent();
 
-Returns the parent node, or C<undef> if there is none (if C<$node> itself is the root)
+Returns the parent node, or undef if there is none (if $node itself is the root)
 
 =item $node->set_parent($parent_node);
 
-Makes C<$node> a child of C<$parent_node>.
+Makes $node a child of $parent_node.
 
 =item $node->remove();
 
-Deletes a node and the subtree rooted by the given node.
+Deletes a node and the a subtree rooted by the given node.
 Node identifier is removed from the document indexing table.
 The removed node cannot be further used.
 
@@ -1068,17 +829,13 @@ The removed node cannot be further used.
 
 Returns the root of the node's tree.
 
-=item $node->is_root();
+=item my $root_node = $node->is_root();
 
-Returns C<true> if the node has no parent.
-
-=item $node->is_leaf();
-
-Returns C<true> if the node has no children.
+Returns true if the node has no parent.
 
 =item $node1->is_descendant_of($node2);
 
-Tests whether C<$node1> is among transitive descendants of C<$node2>;
+Tests whether $node1 is among transitive descendants of $node2;
 
 =back
 
@@ -1138,18 +895,18 @@ Names of variables in the examples suppose a language with left-to-right script.
 
 =item *
 
-C<first_only> and C<last_only> switches makes the method return just one item -
-a scalar, even if combined with the C<add_self> switch.
+B<first_only> and B<last_only> switches makes the method return just one item - a scalar,
+even if combined with the B<add_self> switch.
 
 =item *
 
-Specifying C<(first|last|preceding|following)_only> implies C<ordered>,
-so explicit addition of C<ordered> gives a warning.
+Specifying B<(first|last|preceding|following)_only> implies B<ordered>,
+so explicit addition of B<ordered> gives a warning.
 
 =item *
 
-Specifying both C<preceding_only> and C<following_only> gives an error
-(same for combining C<first_only> and C<last_only>).
+Specifying both B<preceding_only> and B<following_only> gives an error
+(same for combining B<first_only> and B<last_only>).
 
 =back
 
@@ -1173,7 +930,7 @@ Actually, this is shortcut for C<$node-E<gt>get_siblings({following_only=E<gt>1,
 
 =head2 PML-related methods
 
-=over
+=over 4
 
 =item my $type = $node->get_pml_type_name;
 
@@ -1186,30 +943,12 @@ Actually, this is shortcut for C<$node-E<gt>get_siblings({following_only=E<gt>1,
 
 =item add_aligned_node
 
-=item my ($nodes_rf, $types_rf) = $node->get_aligned_nodes();
-
-Returns an array containing two array references. The first array contains the nodes aligned to this node, the second array contains types of the links.
-
-=item my @nodes = $node->get_aligned_nodes_of_type($regex_constraint_on_type);
+=item get_aligned_nodes
 
 =item delete_aligned_node
 
 =item is_aligned_to
 
-=item update_aligned_nodes()
-
-Removes all alignment links leading to nodes which have been deleted.
-
-=back
-
-=head2 References (alignment and other references depending on node subtype)
-
-=over
-
-=item my @refnodes = $node->get_referencing_nodes($ref_type);
-
-Returns an array of nodes referencing this node with the given reference type (e.g. 'alignment', 'a/lex.rf' etc.).
-
 =back
 
 =head2 Other methods
@@ -1218,31 +957,26 @@ Returns an array of nodes referencing this node with the given reference type (e
 
 =item $node->generate_new_id();
 
-Generate new (= so far unindexed) identifier (to be used when creating new
-nodes). The new identifier is derived from the identifier of the root
-(C<< $node->root >>), by adding suffix C<x1> (or C<x2>, if C<...x1> has already
-been indexed, etc.) to the root's C<id>.
+Generate new (=so far unindexed) identifier (to be used when creating new nodes).
+The new identifier is derived from the identifier of the root ($node->root), by adding
+suffix x1 (or x2, if ...x1 has already been indexed, etc.) to the root's id.
+
 
 =item my $levels = $node->get_depth();
 
 Return the depth of the node. The root has depth = 0, its children have depth = 1 etc.
 
-=item my $address = $node->get_address();
+=back
 
-Return the node address, i.e. file name and node's position within the file,
-similarly to TrEd's C<FPosition()> (but the value is only returned, not  printed).
 
-=item $node->equals($another_node)
+=head2 DEPRECATED & QUESTIONABLE METHODS
 
-This is the internal implementation of overloaded C<==> operator,
-which checks whether C<$node == $another_node> (the object instance must be identical).
+=over
 
-=item my $string = $node->to_string()
+=item my $position = $node->get_fposition();
 
-This is the internal implementation of overloaded stringification,
-so you can use e.g. C<print "There is a node $node.">.
-It returns the id (C<$node->id>), but the behavior may be overridden in subclasses.
-See L<overload> pragma for details about overloading operators in Perl.
+Return the node address, i.e. file name and node's position within the file, similarly
+to TrEd's FPosition() (but the value is only returned, not printed).
 
 =back
 
@@ -1255,12 +989,8 @@ Martin Popel <popel@ufal.mff.cuni.cz>
 
 David Mareček <marecek@ufal.mff.cuni.cz>
 
-Daniel Zeman <zeman@ufal.mff.cuni.cz>
-
-Ondřej Dušek <odusek@ufal.mff.cuni.cz>
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2011-2012 by Institute of Formal and Applied Linguistics, Charles University in Prague
+Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
