@@ -1,11 +1,8 @@
 package Treex::Core::Node::InClause;
-{
-  $Treex::Core::Node::InClause::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::Node::InClause::VERSION = '0.05222';
 }
 use Moose::Role;
-
-# with Moose >= 2.00, this must be present also in roles
-use MooseX::SemiAffordanceAccessor;
 use Treex::Core::Log;
 use List::Util qw(first);    # TODO: this wouldn't be needed if there was Treex::Core::Common for roles
 
@@ -49,7 +46,7 @@ sub get_clause_nodes {
     my $root        = $self->get_root();
     my @descendants = $root->get_descendants( { ordered => 1 } );
     my $my_number   = $self->get_attr('clause_number');
-    return grep { ( $_->get_attr('clause_number') || '' ) eq $my_number } @descendants;
+    return grep { $_->get_attr('clause_number') == $my_number } @descendants;
 }
 
 # TODO: same purpose as get_clause_root but instead of clause_number uses is_clause_head
@@ -84,7 +81,7 @@ Treex::Core::Node::InClause
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 DESCRIPTION
 
@@ -142,4 +139,4 @@ Martin Popel <popel@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
