@@ -1,18 +1,14 @@
 package Treex::Core::Node::Ordered;
-{
-  $Treex::Core::Node::Ordered::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::Node::Ordered::VERSION = '0.05222';
 }
 use Moose::Role;
-
-# with Moose >= 2.00, this must be present also in roles
-use MooseX::SemiAffordanceAccessor;
 use Treex::Core::Log;
 use List::Util qw(first);    # TODO: this wouldn't be needed if there was Treex::Core::Common for roles
-use Treex::Core::Types;
 
 has ord => (
     is     => 'ro',
-    isa    => 'Treex::Type::NonNegativeInt',
+    isa    => 'Int',         # TODO non-negative Int
     writer => '_set_ord',
     reader => 'ord',
 );
@@ -117,14 +113,7 @@ sub shift_after_subtree {
     my ( $self, $reference_node, $arg_ref ) = @_;
     _check_shifting_method_args(@_);
 
-    my $last_node;
-    if ( $arg_ref->{without_children} ) {
-        ($last_node) = reverse grep { $_ != $self } $reference_node->get_descendants( { ordered => 1, add_self => 1 } );
-    }
-    else {
-        $last_node = $reference_node->get_descendants( { except => $self, last_only => 1, add_self => 1 } );
-    }
-    return if !defined $last_node;
+    my $last_node = $reference_node->get_descendants( { except => $self, last_only => 1, add_self => 1 } );
     return $self->_shift_to_node( $last_node, 1, $arg_ref->{without_children} ) if $arg_ref;
     return $self->_shift_to_node( $last_node, 1, 0 );
 }
@@ -133,14 +122,7 @@ sub shift_before_subtree {
     my ( $self, $reference_node, $arg_ref ) = @_;
     _check_shifting_method_args(@_);
 
-    my $first_node;
-    if ( $arg_ref->{without_children} ) {
-        ($first_node) = grep { $_ != $self } $reference_node->get_descendants( { ordered => 1, add_self => 1 } );
-    }
-    else {
-        $first_node = $reference_node->get_descendants( { except => $self, first_only => 1, add_self => 1 } );
-    }
-    return if !defined $first_node;
+    my $first_node = $reference_node->get_descendants( { except => $self, first_only => 1, add_self => 1 } );
     return $self->_shift_to_node( $first_node, 0, $arg_ref->{without_children} ) if $arg_ref;
     return $self->_shift_to_node( $first_node, 0, 0 );
 }
@@ -176,8 +158,7 @@ sub _shift_to_node {
 
     # Recompute ord of all nodes.
     # The technical root has ord=0 and the first node will have ord=1.
-    my $counter     = 1;
-    my $nodes_moved = 0;
+    my $counter = 1;
     @all_nodes = sort { $a->ord() <=> $b->ord() } @all_nodes;
     foreach my $node (@all_nodes) {
 
@@ -198,7 +179,6 @@ sub _shift_to_node {
             foreach my $moving_node (@nodes_to_move) {
                 $moving_node->_set_ord( $counter++ );
             }
-            $nodes_moved = 1;
         }
 
         # If moving "before" a node, then now it is the right moment
@@ -207,88 +187,9 @@ sub _shift_to_node {
             $node->_set_ord( $counter++ );
         }
     }
-
-    # If $is_moving{$reference_node}, e.g. when there is just one node in the tree,
-    # we need to do the reordering now (otherwise the ord would be still 10000).
-    if ( !$nodes_moved ) {
-        foreach my $moving_node (@nodes_to_move) {
-            $moving_node->_set_ord( $counter++ );
-        }
-    }
     return;
 }
 
-###!!! DZ: reverting to 7183, 2011-11-03.
-# This function by Martin is faster than the my own below but it does not always return correct results.
-# The key problem could be that it relies on ord values forming a contiguous sequence which might not always be true.
-# Go to devel/normalize_treebanks/nonprojectivity and test that make yields the same numbers for the old and the new method.
-sub is_nonprojective_does_not_work {
-    my ($self) = @_;
-
-    # Root and its children are always projective
-    my $parent = $self->get_parent();
-    return 0 if !$parent || $parent->is_root();
-
-    # Edges between neighbouring nodes are always projective.
-    # Check it now to make it a bit faster.
-    my ( $ordA, $ordB ) = ( $self->ord, $parent->ord );
-    if ( $ordA > $ordB ) {
-        ( $ordA, $ordB ) = ( $ordB, $ordA );
-    }
-    my $distance = $ordB - $ordA;
-    return 0 if $distance == 1;
-
-    # Get all the descendants of $parent that are in the span of the edge.
-    my @span = grep { $_->ord > $ordA && $_->ord < $ordB } $parent->get_descendants();
-
-    # For projective edges @span must include all the nodes between $parent and $self.
-    return @span != $distance - 1;
-}
-
-#------------------------------------------------------------------------------
-# Tells whether the node is attached to its parent nonprojectively, i.e. there
-# is at least one node between this node and its parent that is not dominated
-# by the parent.
-#------------------------------------------------------------------------------
-sub is_nonprojective
-{
-    log_fatal('Incorrect number of arguments') if(scalar(@_)!=1);
-    my $self = shift;
-    my $parent = $self->parent();
-    # A node that does not have a parent cannot be nonprojective.
-    return 0 if(!$parent);
-    # Get a hash of all descendants of the parent.
-    my @pdesc = $parent->get_descendants({add_self=>1});
-    my %pdesc; map {$pdesc{$_}++} (@pdesc);
-    # Figure out whether the node is to the left or to the right from its parent.
-    my $nord = $self->ord();
-    my $pord = $parent->ord();
-    my ($x, $y);
-    if($pord>$nord)
-    {
-        $x = $self;
-        $y = $parent;
-    }
-    else
-    {
-        $x = $parent;
-        $y = $self;
-    }
-    # Get the ordered list of all nodes between $x and $y.
-    my $xord = $x->ord();
-    my $yord = $y->ord();
-    my @between = grep {$_->ord()>$xord && $_->ord()<$yord} ($parent->root()->get_descendants({ordered=>1}));
-    # This node is nonprojective if @between contains anything that is not in %pdesc.
-    foreach my $b (@between)
-    {
-        if(!$pdesc{$b})
-        {
-            return 1;
-        }
-    }
-    return 0;
-}
-
 1;
 
 __END__
@@ -301,7 +202,7 @@ Treex::Core::Node::Ordered
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 DESCRIPTION
 
@@ -350,7 +251,7 @@ or C<undef> if C<$node> is the first one in the tree.
 Next four methods for changing the order of nodes
 (the word order defined by the attribute C<ord>)
 have an optional argument C<$arg_ref> for specifying switches.
-So far there is only one switch - C<without_children>
+So far there is only one switch - B<without_children>
 which is by default set to 0.
 It means that the default behavior is to shift the node
 with all its descendants.
@@ -364,38 +265,26 @@ There is no rehanging (changing parents). The node which is
 going to be shifted must be already added to the tree
 and the reference node must be in the same tree.
 
-For languages with left-to-right script: C<after> means "to the right of"
-and C<before> means "to the left of".
+For languages with left-to-right script: B<after> means "to the right of"
+and B<before> means "to the left of".
 
 =over
 
 =item $node->shift_after_node($reference_node);
 
-Shifts (changes the C<ord> of) the node just behind the reference node.
+Shifts (changes the ord of) the node just behind the reference node.
 
 =item $node->shift_after_subtree($reference_node);
 
-Shifts (changes the C<ord> of) the node behind the subtree of the reference node.
+Shifts (changes the ord of) the node behind the subtree of the reference node.
 
 =item $node->shift_before_node($reference_node);
 
-Shifts (changes the C<ord> of) the node just in front of the reference node.
+Shifts (changes the ord of) the node just in front of the reference node.
 
 =item $node->shift_before_subtree($reference_node);
 
-Shifts (changes the C<ord> of) the node in front of the subtree of the reference node.
-
-=back
-
-=head2 Nonprojectivity
-
-=over
-
-=item my $nonproj = $node->is_nonprojective();
-
-Return 1 if the node is attached to its parent nonprojectively, i.e. there is
-at least one node between this node and its parent that is not descendant of
-the parent. Return 0 otherwise.
+Shifts (changes the ord of) the node in front of the subtree of the reference node.
 
 =back
 
@@ -408,4 +297,4 @@ Martin Popel <popel@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
