@@ -1,6 +1,6 @@
 package Treex::Core::Zone;
-{
-  $Treex::Core::Zone::VERSION = '0.08633_1';
+BEGIN {
+  $Treex::Core::Zone::VERSION = '0.05222';
 }
 
 # antecedent of DocZone and BundleZone
@@ -11,9 +11,9 @@ use MooseX::NonMoose;
 
 extends 'Treex::PML::Struct';
 
-has language => ( is => 'rw', isa => 'Treex::Type::LangCode', required => 1 );
+has language => ( is => 'rw', isa => 'LangCode', required => 1 );
 
-has selector => ( is => 'rw', isa => 'Treex::Type::Selector', default => '' );
+has selector => ( is => 'rw', isa => 'Selector', default => '' );
 
 # Based on source code of Moose::Object::BUILDARGS,
 # but we don't want to copy args (return { %{$_[0]} };).
@@ -87,21 +87,20 @@ __END__
 
 =head1 NAME
 
-Treex::Core::Zone - base class for Zones
+Treex::Core::Zone
 
 =head1 VERSION
 
-version 0.08633_1
+version 0.05222
 
 =head1 DESCRIPTION
 
-C<Treex::Core::Zone> is an abstract class, it is the antecedent
-of L<Treex::Core::DocZone> and
-L<Treex::Core::BundleZone>.
+Treex::Core::Zone is an abstract class, it is the antecedent
+of Treex::Core::DocZone and Treex::Core::BundleZone.
 
 =head1 ATTRIBUTES
 
-C<Treex::Core::Zone> instances have the following attributes:
+Treex::Core::BundleZone instances have the following attributes:
 
 =over 4
 
@@ -117,8 +116,8 @@ C<Treex::Core::Zone> instances have the following attributes:
 
 =item $my $label = $zone->get_label;
 
-I<Zone label> is a string containing the zone's language
-and selector concatenated with 'C<_>'(if the latter one is defined,
+'Zone label' is a string containing the zone's language
+and selector concatenated with '_'(if the latter one is defined,
 otherwise only the language).
 
 =back
@@ -133,4 +132,4 @@ Martin Popel <popel@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
